@@ -11,7 +11,7 @@ define('USE_CHROOT', true);
 
 // Optional script to run for creating/destroying chroot environment,
 // leave empty to disable. This example script can be used to support
-// Sun Java with a chroot (edit the script first!).
+// Oracle (Sun) Java with a chroot (edit the script first!).
 // define('CHROOT_SCRIPT', 'chroot-startstop.sh');
 define('CHROOT_SCRIPT', '');
 
@@ -20,7 +20,7 @@ define('COMPILETIME', 30);
 
 // Maximum memory usage by RUNUSER in kB
 // This includes the shell which starts the compiled solution and
-// also any interpreter like Sun 'java', which takes 200MB away!
+// also any interpreter like Oracle (Sun) 'java', which takes 200MB away!
 define('MEMLIMIT', 524288);
 
 // Maximum filesize RUNUSER may write in kB
@@ -53,15 +53,16 @@ $RESULTS_PRIO = array(
 // Lazy evaluation of results? If enabled, returns final result as
 // soon as a highest priority result is found, otherwise only return
 // final result when all testcases are judged.
-// Note that may especially speed up judging when timelimit has
+// Note that this may especially speed up judging when timelimit has
 // highest priority and a solution would otherwise timeout on a lot of
 // testcases.
 define('LAZY_EVAL_RESULTS', true);
 
-// Remap results, e.g. to disable a specific result. Some possible
-// options are shown commented below.
+// Remap final result, e.g. to disable a specific result.
+// Some possible options are shown commented below. By default
+// presentation errors are remapped to wrong-answer's.
 $RESULTS_REMAP = array(
-//	'presentation-error' => 'wrong-answer',
+	'presentation-error' => 'wrong-answer',
 //	'presentation-error' => 'correct',
 //	'no-output'          => 'wrong-answer',
 	);
