@@ -1,12 +1,12 @@
 #!/bin/sh
-# $Id: chroot-startstop.sh 3209 2010-06-12 00:13:43Z eldering $
+# $Id: chroot-startstop.sh 3397 2010-10-25 12:38:24Z kink $
 
-# Script to setup chroot environment extras needed for Sun Java.
+# Script to setup chroot environment extras needed for Oracle Java.
 #
 # Configure the use of this script in 'etc/judgehost-config.php' when
-# using the chroot environment and Sun Java compiler/interpreter and
+# using the chroot environment and Oracle Java compiler/interpreter and
 # adapt this script to your environment. See also bin/dj_make_chroot.sh
-# for a script to generate a minimal chroot environment with Sun Java.
+# for a script to generate a minimal chroot environment with Oracle Java.
 #
 # This script will be called from testcase_run.sh in the root
 # directory of the chroot environment with one parameter: either
@@ -25,6 +25,7 @@ case "$1" in
 	start)
 
 # Mount (bind) the proc filesystem (needed by Java for /proc/self/stat):
+		mkdir -p proc
 		sudo -S mount -n -t proc --bind /proc proc < /dev/null
 
 		for i in $SUBDIRMOUNTS ; do
@@ -46,6 +47,7 @@ case "$1" in
 		sleep 1
 
 		sudo -S umount "$PWD/proc" < /dev/null
+		rmdir proc || true
 
 		for i in $SUBDIRMOUNTS ; do
 			if [ -L "$CHROOTORIGINAL/$i" ]; then
