@@ -1,7 +1,7 @@
 /*
    compare -- compare program and testdata output and return diff output.
 
-   $Id: compare.c 3235 2010-07-08 19:17:25Z eldering $
+   $Id: compare.c 3573 2011-07-24 19:30:26Z eldering $
 
    This program is a compare script for 'testcase_run.sh' and executes
    a normal 'diff' to detect correct, presentation-error (whitespace
@@ -24,9 +24,11 @@
    Output format of differences:
 
    - First a line stating from which line differences were found.
-   - Then all lines from that line until end of both <program.out> and
-     <testdata.out> formatted as
-	 '<PROGRAM LINE>' X '<TESTDATA LINE>'
+   - Then all lines from PREVLINES before that line until end of both
+     <program.out> and <testdata.out>, formatted as:
+
+	   '<PROGRAM LINE>' X '<TESTDATA LINE>'
+
 	 The left and right sides are aligned and ending quote (') is
      replaced by an underscore (_) if the line is truncated. The
      middle 'X' is one of the following characters:
@@ -39,6 +41,8 @@
        characters are stripped.
  */
 
+#include "config.h"
+
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -52,9 +56,11 @@
 #define min(a,b) ((a) < (b) ? (a) : (b))
 #define max(a,b) ((a) > (b) ? (a) : (b))
 
-#define MAXLINELEN 65536
+/* Maximum characters to print per side on a line */
+#define MAXPRINTLEN 60
 
-const size_t maxprintlen = 80;
+/* Number of context lines printed before first line with differences */
+#define PREVLINES 3
 
 char *progname;
 
@@ -137,7 +143,7 @@ int main(int argc, char **argv)
 int execdiff(int ignore_ws)
 {
 	int redir_fd[3];
-	char *cmdargs[MAXARGS];
+	char *cmdargs[4];
 	pid_t cpid;
 	FILE *rpipe;
 	int status, differror;
@@ -152,9 +158,9 @@ int execdiff(int ignore_ws)
 	cmdargs[1] = "-U0";
 	cmdargs[2] = progout;
 	cmdargs[3] = testout;
-	redir_fd[0] = 0;
-	redir_fd[1] = 1;
-	redir_fd[2] = 0;
+	redir_fd[0] = FDREDIR_NONE;
+	redir_fd[1] = FDREDIR_PIPE;
+	redir_fd[2] = FDREDIR_NONE;
 	if ( (cpid = execute("diff",cmdargs,4,redir_fd,1))<0 ) {
 		error(errno,"running diff");
 	}
@@ -192,7 +198,8 @@ void writediff()
 	FILE *diffoutfile;
 	FILE *inputfile[2];
 	size_t maxlinelen[2], nlines[2];
-	char line[2][MAXLINELEN];
+	char *line[2];
+	size_t linesize[2];
 	int endoffile[2];
 	int i;
 	size_t l;
@@ -200,14 +207,18 @@ void writediff()
 	char diffchar, quotechar[2];
 	char formatstr[256];
 	int firstdiff = -1;
-	char *dummy;
 
 	if ( (diffoutfile =fopen(diffout,"w"))==NULL ) error(errno,"opening file '%s'",diffout);
 	if ( (inputfile[0]=fopen(progout,"r"))==NULL ) error(errno,"opening file '%s'",progout);
 	if ( (inputfile[1]=fopen(testout,"r"))==NULL ) error(errno,"opening file '%s'",testout);
 
-	/* Find maximum line length and no. lines per input file: */
-	for(i=0; i<2; i++) endoffile[i] = maxlinelen[i] = nlines[i] = 0;
+	/* Find maximum line length and no. lines per input file.
+	 * First initialize variables.
+	 */
+	for(i=0; i<2; i++) {
+		line[i] = NULL;
+		endoffile[i] = maxlinelen[i] = nlines[i] = linesize[i] = 0;
+	}
 
 	/* Read lines until end of file to find first difference and maxlinelen */
 	for(l=0; !(endoffile[0] && endoffile[1]); l++) {
@@ -218,9 +229,10 @@ void writediff()
 				line[i][0] = 0;
 				continue;
 			}
-			if ( fgets(line[i],MAXLINELEN,inputfile[i])!=NULL && strlen(line[i])!=0 ) {
+			if ( getline(&line[i],&linesize[i],inputfile[i])>=0 ) {
 				nlines[i]++;
 			} else {
+				/* We assume no errors other than EOF occur */
 				endoffile[i] = 1;
 				line[i][0] = 0;
 			}
@@ -238,26 +250,29 @@ void writediff()
 		}
 	}
 
+	/* If no differences found, then some error occurred */
+	if ( firstdiff==-1 ) error(0,"differences reported by 'diff', but none found");
+
 	/* Reset file position to start */
 	for(i=0; i<2; i++) rewind(inputfile[i]);
 
 	/* Determine left/right printing length and construct format
 	   string for printf later */
-	for(i=0; i<2; i++) maxlinelen[i] = min(maxlinelen[i],maxprintlen);
+	for(i=0; i<2; i++) maxlinelen[i] = min(maxlinelen[i],MAXPRINTLEN);
 	sprintf(formatstr,"%%3d %%c%%-%ds %%c %%c%%-%ds\n",
 	        (int)maxlinelen[0]+1, (int)maxlinelen[1]+1);
 
 	/* Print first differences found header at beginning of file */
 	fprintf(diffoutfile,"### DIFFERENCES FROM LINE %d ###\n",firstdiff+1);
+	fprintf(diffoutfile,"%*s ? REFERENCE\n",(int)maxlinelen[0]+6,"TEAM");
 
 	/* Loop over all common lines for printing */
 	for(l=0; l<min(nlines[0],nlines[1]); l++) {
 
-		/* Assign fgets return value to dummy variable to suppress
-		 * compiler warning. We should check fgets() returning NULL on
+		/* We should check getline() returning -1 on
 		 * EOF or errors, but we did so above.
 		 */
-		for(i=0; i<2; i++) dummy = fgets(line[i],MAXLINELEN,inputfile[i]);
+		for(i=0; i<2; i++) getline(&line[i],&linesize[i],inputfile[i]);
 
 		/* Check for endline (or normal) character differences */
 		endlinediff = ( strcmp(line[0],line[1])!=0 );
@@ -268,6 +283,22 @@ void writediff()
 		/* Check for just normal character differences */
 		normaldiff = ( strcmp(line[0],line[1])!=0 );
 
+		/* Discern cases '!', '$' and '=' */
+		if ( normaldiff ) {
+			diffchar = '!';
+		} else if ( endlinediff ) {
+			diffchar = '$';
+		} else {
+			diffchar = '=';
+		}
+
+		if ( diffchar!='=' && l<firstdiff ) {
+			error(0,"internal error: first difference on line %d != %d",l,firstdiff);
+		}
+
+		/* Skip printing until PREVLINES before first difference line */
+		if ( l+PREVLINES<firstdiff ) continue;
+
 		/* Truncate lines for printing */
 		for(i=0; i<2; i++) {
 			if ( strlen(line[i])>maxlinelen[i] ) {
@@ -279,15 +310,6 @@ void writediff()
 			}
 		}
 
-		/* Discern cases '!', '$' and '=' */
-		if ( normaldiff ) {
-			diffchar = '!';
-		} else if ( endlinediff ) {
-			diffchar = '$';
-		} else {
-			diffchar = '=';
-		}
-
 		fprintf(diffoutfile,formatstr,l+1,'\'',line[0],diffchar,'\'',line[1]);
 	}
 
@@ -306,11 +328,10 @@ void writediff()
 		}
 
 		for(; l<nlines[i]; l++) {
-			/* Assign fgets return value to dummy variable to suppress
-			 * compiler warning. We should check fgets() returning NULL on
+			/* We should check fgets() returning -1 on
 			 * EOF or errors, but we did so above.
 			 */
-			dummy = fgets(line[i],MAXLINELEN,inputfile[i]);
+			getline(&line[i],&linesize[i],inputfile[i]);
 
 			stripendline(line[i]);
 
@@ -329,9 +350,6 @@ void writediff()
 		}
 	}
 
-	/* If no differences found, then some error occurred */
-	if ( firstdiff==-1 ) error(0,"differences reported by 'diff', but none found");
-
 	fclose(diffoutfile);
 	fclose(inputfile[0]);
 	fclose(inputfile[1]);
