@@ -3,7 +3,7 @@
  * Request a yet unjudged submission from the database, judge it, and pass
  * the results back in to the database.
  *
- * $Id: judgedaemon.main.php 3356 2010-08-19 19:08:33Z eldering $
+ * $Id: judgedaemon.main.php 3724 2011-11-09 13:36:59Z kink $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -40,12 +40,41 @@ $myhost = trim(`hostname | cut -d . -f 1`);
 
 define ('SCRIPT_ID', 'judgedaemon');
 define ('LOGFILE', LOGDIR.'/judge.'.$myhost.'.log');
+define ('PIDFILE', RUNDIR.'/judgedaemon.pid');
+
+// Pass SYSLOG variable via environment for compare program
+if ( defined('SYSLOG') && SYSLOG ) putenv('DJ_SYSLOG=' . SYSLOG);
 
 require(LIBDIR . '/init.php');
 
+function usage()
+{
+	echo "Usage: " . SCRIPT_ID . " [OPTION]...\n" .
+	    "Start the judgedaemon.\n\n" .
+	    "  -d       daemonize after startup\n" .
+	    "  -v       set verbosity to LEVEL (syslog levels)\n" .
+	    "  -h       display this help and exit\n" .
+	    "  -V       output version information and exit\n\n";
+	exit;
+}
+
+$options = getopt("dv:hV");
+// FIXME: getopt doesn't return FALSE on parse failure as documented!
+if ( $options===FALSE ) {
+	echo "Error: parsing options failed.\n";
+	usage();
+}
+if ( isset($options['d']) ) $options['daemon']  = $options['d'];
+if ( isset($options['v']) ) $options['verbose'] = $options['v'];
+
+if ( isset($options['V']) ) version();
+if ( isset($options['h']) ) usage();
+
 setup_database_connection('jury');
 
 $verbose = LOG_INFO;
+if ( isset($options['verbose']) ) $verbose = $options['verbose'];
+
 if ( DEBUG & DEBUG_JUDGE ) {
 	$verbose = LOG_DEBUG;
 	putenv('DEBUG=1');
@@ -68,6 +97,8 @@ if ( version_compare(PHP_VERSION, '5.3', '<' ) ) {
 }
 initsignals();
 
+if ( isset($options['daemon']) ) daemonize(PIDFILE);
+
 database_retry_connect($waittime);
 
 $first = True;
@@ -182,7 +213,7 @@ while ( TRUE ) {
 	// to be judged, and also prevents throwing away the query cache every
 	// single time
 	$numopen = $DB->q('VALUE SELECT COUNT(*) FROM submission
-	                   WHERE judgehost IS NULL AND cid = %i AND langid IN (%As)
+	                   WHERE judgemark IS NULL AND cid = %i AND langid IN (%As)
 	                   AND probid IN (%As) AND submittime < %s AND valid = 1',
 	                  $cid, $judgable_lang, $judgable_prob, $contdata['endtime']);
 
@@ -197,7 +228,7 @@ while ( TRUE ) {
 		// us to it
 		$numupd = $DB->q('RETURNAFFECTED UPDATE submission
 				  SET judgehost = %s, judgemark = %s
-				  WHERE judgehost IS NULL AND cid = %i AND langid IN (%As)
+				  WHERE judgemark IS NULL AND cid = %i AND langid IN (%As)
 				  AND probid IN (%As) AND submittime < %s AND valid = 1
 				  LIMIT 1',
 				 $myhost, $mark, $cid, $judgable_lang, $judgable_prob,
@@ -220,7 +251,7 @@ while ( TRUE ) {
 	// get maximum runtime, source code and other parameters
 	$row = $DB->q('TUPLE SELECT CEILING(time_factor*timelimit) AS maxruntime,
 	               s.submitid, s.sourcecode, s.langid, s.teamid, s.probid,
-	               p.special_run, p.special_compare, l.extension
+	               p.special_run, p.special_compare
 	               FROM submission s, problem p, language l
 	               WHERE s.probid = p.probid AND s.langid = l.langid AND
 	               judgemark = %s AND judgehost = %s', $mark, $myhost);
@@ -260,15 +291,14 @@ function judge($mark, $row, $judgingid)
 	if ( $retval != 0 ) error("Could not create '$workdir/compile'");
 
 	// Get the source code from the DB and store in a file
-	$srcfile = "$workdir/compile/source.$row[extension]";
+	$srcfile = "$workdir/compile/source.$row[langid]";
 	if ( file_put_contents($srcfile, $row['sourcecode']) === FALSE ) {
 		error("Could not create $srcfile");
 	}
 	unset($row['sourcecode']);
 
 	// Compile the program.
-	system(LIBJUDGEDIR . "/compile.sh $row[extension] $row[langid] " .
-	       "'$workdir'", $retval);
+	system(LIBJUDGEDIR . "/compile.sh $row[langid] '$workdir'", $retval);
 
 	// what does the exitcode mean?
 	if( ! isset($EXITCODES[$retval]) ) {
@@ -307,7 +337,7 @@ function judge($mark, $row, $judgingid)
 		    $tc['md5sum_'.$inout] . "." . substr($inout, 0, -3);
 
 		if ( !file_exists($tcfile[$inout]) ) {
-			$content = $DB->q("VALUE SELECT $inout FROM testcase
+			$content = $DB->q("VALUE SELECT SQL_NO_CACHE $inout FROM testcase
 	 		                   WHERE testcaseid = %i", $tc['testcaseid']);
 			if ( file_put_contents($tcfile[$inout] . ".new", $content) === FALSE ) {
 				error("Could not create $tcfile[$inout].new");
@@ -330,11 +360,12 @@ function judge($mark, $row, $judgingid)
 
 	// Copy program with all possible additional files to testcase
 	// dir. Use hardlinks to preserve space with big executables.
-	system("mkdir -p '$testcasedir'", $retval);
-	if ( $retval!=0 ) error("Could not create directory '$testcasedir'");
+	$programdir = $testcasedir . '/execdir';
+	system("mkdir -p '$programdir'", $retval);
+	if ( $retval!=0 ) error("Could not create directory '$programdir'");
 
-	system("cp -dpRl '$workdir'/compile/* '$testcasedir'", $retval);
-	if ( $retval!=0 ) error("Could not copy program to '$testcasedir'");
+	system("cp -pPRl '$workdir'/compile/* '$programdir'", $retval);
+	if ( $retval!=0 ) error("Could not copy program to '$programdir'");
 
 	// do the actual test-run
 	system(LIBJUDGEDIR . "/testcase_run.sh $tcfile[input] $tcfile[output] " .
