@@ -5,7 +5,7 @@
    Based on an idea from the timeout program, written by Wietse Venema
    as part of The Coroner's Toolkit.
 
-   $Id: runguard.c 3302 2010-08-09 18:39:20Z eldering $
+   $Id: runguard.c 3602 2011-08-17 12:57:40Z eldering $
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -37,8 +37,9 @@
    has passed, followed by a SIGKILL after 'killdelay'.
  */
 
-/* For having access to isfinite() macro in math.h and some functions. */
-#define _ISOC99_SOURCE
+#include "config.h"
+
+/* For chroot(), which is not POSIX. */
 #define _BSD_SOURCE
 
 #include <sys/types.h>
@@ -58,12 +59,13 @@
 #include <grp.h>
 #include <time.h>
 #include <math.h>
+#include <limits.h>
 
 /* Some system/site specific config: VALID_USERS, CHROOT_PREFIX */
-#include "../etc/runguard-config.h"
+#include "runguard-config.h"
 
 #define PROGRAM "runguard"
-#define VERSION "$Rev: 3302 $"
+#define VERSION "$Rev: 3602 $"
 #define AUTHORS "Jaap Eldering"
 
 const struct timespec killdelay = { 0, 100000000L }; /* 0.1 seconds */
@@ -95,7 +97,7 @@ int be_quiet;
 int show_help;
 int show_version;
 
-long long runtime; /* in microseconds */
+unsigned long runtime; /* in microseconds */
 rlim_t cputime;
 rlim_t memsize;
 rlim_t filesize;
@@ -191,25 +193,27 @@ void usage()
 	printf("\
 Usage: %s [OPTION]... COMMAND...\n\
 Run COMMAND with restrictions.\n\
-\n\
+\n", progname);
+	printf("\
   -r, --root=ROOT      run COMMAND with root directory set to ROOT\n\
   -u, --user=USER      run COMMAND as user with username or ID USER\n\
   -g, --group=GROUP    run COMMAND under group with name or ID GROUP\n\
   -t, --time=TIME      kill COMMAND if still running after TIME seconds (float)\n\
   -C, --cputime=TIME   set maximum CPU time to TIME seconds (integer)\n\
   -m, --memsize=SIZE   set all (total, stack, etc) memory limits to SIZE kB\n\
-  -f, --filesize=SIZE  set maximum created filesize to SIZE kB\n\
+  -f, --filesize=SIZE  set maximum created filesize to SIZE kB\n");
+	printf("\
   -p, --nproc=N        set maximum no. processes to N\n\
   -c, --no-core        disable core dumps\n\
   -o, --output=FILE    write actual runtime to FILE\n\
   -v, --verbose        display some extra warnings and information\n\
   -q, --quiet          suppress all warnings and verbose output\n\
       --help           display this help and exit\n\
-      --version        output version information and exit\n\
-\n\
+      --version        output version information and exit\n");
+	printf("\n\
 Note that root privileges are needed for the `root' and `user' options.\n\
 When run setuid without the `user' option, the user ID is set to the\n\
-real user ID.\n",progname);
+real user ID.\n");
 	exit(0);
 }
 
@@ -223,7 +227,7 @@ void outputtime()
 	timediff = (endtime.tv_sec  - starttime.tv_sec ) +
 	           (endtime.tv_usec - starttime.tv_usec)*1E-6;
 
-	verbose("runtime is %.3lf seconds",timediff);
+	verbose("runtime is %.3f seconds",timediff);
 
 	if ( use_output ) {
 		verbose("writing runtime to file `%s'",outputfilename);
@@ -231,7 +235,7 @@ void outputtime()
 		if ( (outputfile = fopen(outputfilename,"w"))==NULL ) {
 			error(errno,"cannot open `%s'",outputfilename);
 		}
-		if ( fprintf(outputfile,"%.3lf\n",timediff)==0 ) {
+		if ( fprintf(outputfile,"%.3f\n",timediff)==0 ) {
 			error(0,"cannot write to file `%s'",outputfile);
 		}
 		if ( fclose(outputfile) ) {
@@ -343,7 +347,6 @@ void setrestrictions()
 	setlim(AS);
 	setlim(DATA);
 	setlim(STACK);
-	setlim(MEMLOCK);
 
 	if ( filesize!=RLIM_INFINITY ) {
 		verbose("setting filesize limit to %d bytes",(int)filesize);
@@ -460,10 +463,11 @@ int main(int argc, char **argv)
 		case 't': /* time option */
 			use_time = 1;
 			runtime_d = strtod(optarg,&ptr);
-			if ( errno || *ptr!='\0' || !isfinite(runtime_d) || runtime_d<=0 ) {
+			if ( errno || *ptr!='\0' ||
+			     runtime_d<=0 || runtime_d>=ULONG_MAX*1E-6 ) {
 				error(errno,"invalid runtime specified: `%s'",optarg);
 			}
-			runtime = (int)(runtime_d*1E6);
+			runtime = (unsigned long)(runtime_d*1E6);
 			break;
 		case 'C': /* CPU time option */
 			cputime = (rlim_t) readoptarg("CPU-time limit",1,LONG_MAX);
@@ -593,7 +597,7 @@ int main(int argc, char **argv)
 			if ( setitimer(ITIMER_REAL,&itimer,NULL)!=0 ) {
 				error(errno,"setting timer");
 			}
-			verbose("using timelimit of %.3lf seconds",runtime*1E-6);
+			verbose("using timelimit of %.3f seconds",runtime*1E-6);
 		}
 
 		/* Wait for the child command to finish */
@@ -611,10 +615,6 @@ int main(int argc, char **argv)
 				warning("command terminated with signal %d",WTERMSIG(status));
 				return 128+WTERMSIG(status);
 			}
-			if ( WIFSTOPPED(status) ) {
-				warning("command stopped with signal %d",WSTOPSIG(status));
-				return 128+WSTOPSIG(status);
-			}
 			error(0,"command exit status unknown: %d",status);
 		}
 
