@@ -1,7 +1,7 @@
 /*
  * Functions for reading runtime configuration files
  *
- * $Id: lib.config.h 3080 2010-02-11 14:09:34Z schot $
+ * $Id: lib.config.h 3316 2010-08-14 10:13:37Z eldering $
  */
 
 #ifndef LIB_CONFIG_H
@@ -21,4 +21,4 @@ int   config_readfile(const char *);
 }
 #endif
 
-#endif // LIB_CONFIG_H
+#endif /* LIB_CONFIG_H */
