@@ -1,7 +1,7 @@
 /*
  * Error handling and logging functions
  *
- * $Id: lib.error.c 3209 2010-06-12 00:13:43Z eldering $
+ * $Id: lib.error.c 3496 2010-12-12 13:31:39Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -16,6 +16,8 @@
  * turn calls errorstring to generate the actual error message;
  */
 
+#include "config.h"
+
 #include "lib.error.h"
 
 #include <stdlib.h>
@@ -23,8 +25,10 @@
 #include <unistd.h>
 #include <time.h>
 
-/* For SYSLOG config variable */
-#include "../etc/config.h"
+/* Define va_copy macro if not available (ANSI C99 only) */
+#ifndef va_copy
+#define va_copy(dest, src) memcpy(&dest, &src, sizeof(va_list))
+#endif
 
 /* Use program name in syslogging if defined */
 #ifndef PROGRAM
@@ -50,6 +54,8 @@ void vlogmsg(int msglevel, const char *mesg, va_list ap)
 	int mesglen = (mesg==NULL ? 0 : strlen(mesg));
 	int bufferlen;
 	va_list aq;
+	char *str, *endptr;
+	int syslog_fac;
 
 	/* Try to open logfile if it is defined */
 #ifdef LOGFILE
@@ -57,12 +63,13 @@ void vlogmsg(int msglevel, const char *mesg, va_list ap)
 #endif
 
 	/* Try to open syslog if it is defined */
-#ifdef SYSLOG
-	if ( ! syslog_open ) {
-		openlog(PROGRAM, LOG_NDELAY | LOG_PID, SYSLOG);
-		syslog_open = 1;
+	if ( ! syslog_open && (str=getenv("DJ_SYSLOG"))!=NULL ) {
+		syslog_fac = strtol(str,&endptr,10);
+		if ( *endptr==0 ) {
+			openlog(PROGRAM, LOG_NDELAY | LOG_PID, syslog_fac);
+			syslog_open = 1;
+		}
 	}
-#endif
 
 	currtime = time(NULL);
 	strftime(timestring, sizeof(timestring), "%b %d %H:%M:%S", localtime(&currtime));
@@ -89,13 +96,11 @@ void vlogmsg(int msglevel, const char *mesg, va_list ap)
 
 	free(buffer);
 
-#ifdef SYSLOG
-	if ( msglevel<=loglevel ) {
+	if ( msglevel<=loglevel && syslog_open ) {
 		buffer = vallocstr(mesg, ap);
 		syslog(msglevel, "%s", buffer);
 		free(buffer);
 	}
-#endif
 }
 
 /* Argument-list wrapper function around vlogmsg */
