@@ -1,16 +1,20 @@
 /*
  * Error handling and logging functions
  *
- * $Id: lib.error.h 3178 2010-05-24 14:37:46Z eldering $
+ * $Id: lib.error.h 3496 2010-12-12 13:31:39Z eldering $
  */
 
-#ifndef __LIB_ERROR_H
-#define __LIB_ERROR_H
+#ifndef LIB_ERROR_H
+#define LIB_ERROR_H
 
 #include <stdarg.h>
 #include <stdio.h>
-#include <syslog.h>
 #include <errno.h>
+#ifdef HAVE_SYSLOG_H
+#include <syslog.h>
+#else
+#error "Syslog header file not available."
+#endif
 
 #define ERRSTR    "error"
 #define ERRMATCH  ERRSTR": "
@@ -93,4 +97,4 @@ char *vallocstr(const char *, va_list);
 }
 #endif
 
-#endif /* __LIB_ERROR_H */
+#endif /* LIB_ERROR_H */
