@@ -1,6 +1,6 @@
 # Error handling and logging functions
 #
-# $Id: lib.error.sh 2649 2009-04-10 15:17:02Z eldering $
+# $Id: lib.error.sh 3337 2010-08-15 14:09:47Z eldering $
 
 # Loglevels (as defined in syslog.h)
 LOG_EMERG=0
@@ -32,7 +32,7 @@ logmsg ()
 			echo "$stamp $msg" >>$LOGFILE
 		fi
 		if [ "$SYSLOG" ]; then
-			logger -i -t "$PROGNAME" -p "${SYSLOG#LOG_}.$msglevel" "$msg" &> /dev/null
+			logger -i -t "$PROGNAME" -p "${SYSLOG#LOG_}.$msglevel" "$msg" >/dev/null 2>&1
 		fi
 	fi
 }
@@ -40,7 +40,7 @@ logmsg ()
 error ()
 {
 	set +e
-	trap - ERR
+	trap - EXIT
 
 	if [ "$@" ]; then
 		logmsg $LOG_ERR "error: $@"
