@@ -1,18 +1,19 @@
 /*
  * Miscellaneous common functions for C/C++ programs.
  *
- * $Id: lib.misc.h 3209 2010-06-12 00:13:43Z eldering $
+ * $Id: lib.misc.h 3316 2010-08-14 10:13:37Z eldering $
  */
 
-#ifndef __LIB_MISC_H
-#define __LIB_MISC_H
+#ifndef LIB_MISC_H
+#define LIB_MISC_H
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-/* Maximum arguments to execute() */
-#define MAXARGS 10
+/* I/O redirection options for execute() */
+#define FDREDIR_NONE -1
+#define FDREDIR_PIPE -2
 
 /* Define wrapper around true function '_alert' to allow passing
  * LIBDIR as defined in calling program. */
@@ -32,10 +33,11 @@ int execute(const char *, char **, int, int[3], int);
  * char *args[]     array of arguments to command
  * int nargs        number of arguments specified
  * int stdio_fd[3]  File descriptors for stdin, stdout and stderr respectively.
- *                    Set any combination of these to non-zero to redirect IO
- *                    for those. each non-zero element will be set to a file
- *                    descriptor pointing to a pipe to the respective stdio's
- *                    of the command.
+ *                    Each can separately be set to one of the following:
+ *                      FDREDIR_NONE - don't do redirection
+ *                      FDREDIR_PIPE - connect to pipe and set value to file
+ *                                     descriptor of other end of the pipe
+ *                      fd >= 0      - make this a duplicate of <fd>
  * int err2out      Set non-zero to redirect command stderr to stdout. When set
  *                    the redirection of stderr by stdio_fd[2] is ignored.
  *
@@ -58,6 +60,18 @@ void initsignals();
  * return on receiving a signal.
  */
 
+void daemonize(const char *);
+/* Forks and detaches the current process to run as a daemon. Similar
+ * to the daemon() call present in Linux and *BSD, but implented here,
+ * because it is not specified by POSIX, SUSv2 or SVr4.
+ *
+ * Arguments:
+ * char *pidfile    pidfile to check for running instances and write PID;
+ *                    set to NULL to not use a pidfile.
+ *
+ * Either returns successfully or exits with an error.
+ */
+
 char *stripendline(char *);
 /* Removes end-of-line characters (CR and LF) from string. Returns the
  * original pointer to the modified string. */
@@ -66,4 +80,4 @@ char *stripendline(char *);
 }
 #endif
 
-#endif /* __LIB_MISC_H */
+#endif /* LIB_MISC_H */
