@@ -2,7 +2,7 @@
 /**
  * Miscellaneous helper functions
  *
- * $Id: lib.misc.php 3402 2010-10-27 19:47:17Z kink $
+ * $Id: lib.misc.php 3575 2011-07-30 11:28:24Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -11,6 +11,9 @@
 /** Constant to define MySQL datetime format in strftime() function notation. */
 define('MYSQL_DATETIME_FORMAT', '%Y-%m-%d %H:%M:%S');
 
+/** Perl regex class of allowed characters in identifier strings. */
+define('IDENTIFIER_CHARS', '[a-zA-Z0-9_-]');
+
 /**
  * helperfunction to read all contents from a file.
  * If $sizelimit is true (default), then only limit this to
@@ -190,7 +193,6 @@ function getFinalResult($runresults)
 		rsort($tmp);
 		$maxprio = reset($tmp);
 
-//		echo "maxprio = $maxprio\n";
 		// No highest priority result found: no final answer yet.
 		if ( $havenull && $bestprio<$maxprio ) return NULL;
 	}
@@ -203,6 +205,32 @@ function getFinalResult($runresults)
 	}
 }
 
+/**
+ * Parse language extensions from LANG_EXTS to ext -> ID map
+ */
+function parseLangExts()
+{
+	global $langexts;
+
+	$langexts = array();
+	foreach ( explode(' ', LANG_EXTS) as $lang ) {
+		$exts = explode(',', $lang);
+		for ($i=1; $i<count($exts); $i++) $langexts[$exts[$i]] = $exts[1];
+	}
+}
+
+/**
+ * Get langid from extension (initialize global $langexts if necessary)
+ */
+function getLangID($ext)
+{
+	global $langexts;
+
+	if ( empty($langexts) ) parseLangExts();
+
+	return @$langexts[$ext];
+}
+
 /**
  * Simulate MySQL NOW() function to create insert queries that do not
  * change when replicated later.
@@ -424,17 +452,60 @@ function initsignals()
 	pcntl_signal(SIGINT, "sig_handler");
 }
 
+/**
+ * Forks and detaches the current process to run as a daemon. Similar
+ * to the daemon() call present in Linux and *BSD.
+ *
+ * Argument pidfile is an optional filename to check for running
+ * instances and write PID to.
+ *
+ * Either returns successfully or exits with an error.
+ */
+function daemonize($pidfile = NULL)
+{
+	switch ( $pid = pcntl_fork() ) {
+	case -1: error("cannot fork daemon");
+	case  0: break; // child process: do nothing here.
+	default: exit;  // parent process: exit.
+	}
+
+	if ( ($pid = posix_getpid())===FALSE ) error("failed to obtain PID");
+
+	// Check and write PID to file
+	if ( !empty($pidfile) ) {
+		if ( ($fd=@fopen($pidfile, 'x+'))===FALSE ) {
+			error("cannot create pidfile '$pidfile'");
+		}
+		$str = "$pid\n";
+		if ( @fwrite($fd, $str)!=strlen($str) ) {
+			error(errno, "failed writing PID to file");
+		}
+		register_shutdown_function('unlink', $pidfile);
+	}
+
+	// Notify user with daemon PID before detaching from TTY.
+	logmsg(LOG_NOTICE, "daemonizing with PID = $pid");
+
+	// Close std{in,out,err} file descriptors
+	if ( !fclose(STDIN ) ||
+	     !fclose(STDOUT) ||
+	     !fclose(STDERR) ) error("cannot close stdio files");
+
+	// Start own process group, detached from any tty
+	if ( posix_setsid()<0 ) error("cannot set daemon process group");
+}
+
 /**
  * This function takes a temporary file of a submission,
  * validates it and puts it into the database. Additionally it
  * moves it to a backup storage.
  */
-function submit_solution($team, $prob, $langext, $file)
+function submit_solution($team, $prob, $lang, $file)
 {
-	if( empty($team)    ) error("No value for Team.");
-	if( empty($prob)    ) error("No value for Problem.");
-	if( empty($langext) ) error("No value for Language.");
-	if( empty($file)    ) error("No value for Filename.");
+	if( empty($team) ) error("No value for Team.");
+	if( empty($prob) ) error("No value for Problem.");
+	if( empty($lang) ) error("No value for Language.");
+	if( empty($file) ) error("No value for Filename.");
 
 	global $cdata,$cid, $DB;
 
@@ -446,9 +517,9 @@ function submit_solution($team, $prob, $langext, $file)
 	}
 
 	// Check 2: valid parameters?
-	if( ! $lang = $DB->q('MAYBEVALUE SELECT langid FROM language WHERE
-						  extension = %s AND allow_submit = 1', $langext) ) {
-		error("Language '$langext' not found in database or not submittable.");
+	if( ! $langid = $DB->q('MAYBEVALUE SELECT langid FROM language WHERE
+						  langid = %s AND allow_submit = 1', $lang) ) {
+		error("Language '$lang' not found in database or not submittable.");
 	}
 	if( ! $login = $DB->q('MAYBEVALUE SELECT login FROM team WHERE login = %s',$team) ) {
 		error("Team '$team' not found in database.");
@@ -471,15 +542,15 @@ function submit_solution($team, $prob, $langext, $file)
 	$id = $DB->q('RETURNID INSERT INTO submission
 				  (cid, teamid, probid, langid, submittime, sourcecode)
 				  VALUES (%i, %s, %s, %s, %s, %s)',
-				 $cid, $team, $probid, $lang, $now,
+				 $cid, $team, $probid, $langid, $now,
 				 getFileContents($file, false));
 
 	// Log to event table
 	$DB->q('INSERT INTO event (eventtime, cid, teamid, langid, probid, submitid, description)
 			VALUES(%s, %i, %s, %s, %s, %i, "problem submitted")',
-		   now(), $cid, $team, $lang, $prob, $id);
+		   now(), $cid, $team, $langid, $probid, $id);
 
-	$tofile = getSourceFilename($cid,$id,$team,$prob,$langext);
+	$tofile = getSourceFilename($cid,$id,$team,$probid,$langid);
 	$topath = SUBMITDIR . "/$tofile";
 
 	if ( is_writable( SUBMITDIR ) ) {
@@ -492,7 +563,7 @@ function submit_solution($team, $prob, $langext, $file)
 	}
 
 	if( difftime($cdata['endtime'], $now) <= 0 ) {
-		warning("The contest is closed, submission stored but not processed. [c$cid]");
+		logmsg(LOG_INFO, "The contest is closed, submission stored but not processed. [c$cid]");
 	}
 
 	return $id;
@@ -501,9 +572,9 @@ function submit_solution($team, $prob, $langext, $file)
 /**
  * Compute the filename of a given submission.
  */
-function getSourceFilename($cid,$sid,$team,$prob,$langext)
+function getSourceFilename($cid,$sid,$team,$prob,$lang)
 {
-	return "c$cid.s$sid.$team.$prob.$langext";
+	return "c$cid.s$sid.$team.$prob.$lang";
 }
 
 /**
