@@ -2,7 +2,7 @@
 /**
  * Clarification helper functions for jury and teams
  *
- * $Id: clarification.php 3402 2010-10-27 19:47:17Z kink $
+ * $Id: clarification.php 3487 2010-12-05 12:17:52Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -90,7 +90,7 @@ function putClar($clar)
 	echo printtime($clar['submittime']);
 	echo "</td></tr>\n";
 
-	echo '<tr><td valign="top"></td><td class="filename">';
+	echo '<tr><td></td><td class="filename">';
 	echo '<pre class="output_text">' . htmlspecialchars(wrap_unquoted($clar['body'],80)) . "</pre>";
 	echo "</td></tr>\n";
 
@@ -156,10 +156,14 @@ function putClarificationList($clars, $team = NULL)
 	}
 
 	echo "<table class=\"list sortable\">\n<thead>\n";
-	echo "<tr><th scope=\"col\">ID</th><th scope=\"col\">from</th>" .
-	     "<th scope=\"col\">to</th><th scope=\"col\">subject</th>" .
+	echo "<tr>" .
+		( IS_JURY ? "<th scope=\"col\">ID</th>" : "") .
 	     "<th scope=\"col\">time</th>" .
-	     "<th scope=\"col\">text</th></tr>\n</thead>\n<tbody>\n";
+	     "<th scope=\"col\">from</th>" .
+	     "<th scope=\"col\">to</th><th scope=\"col\">subject</th>" .
+	     "<th scope=\"col\">text</th>" .
+		( IS_JURY ? "<th scope=\"col\">answered</th><th scope=\"col\">by</th>" : "") .
+	     "</tr>\n</thead>\n<tbody>\n";
 
 	while ( $clar = $clars->next() ) {
 		// check viewing permission for teams
@@ -174,7 +178,11 @@ function putClarificationList($clars, $team = NULL)
 		else
 			echo '<tr>';
 
-		echo '<td>' . $link . $clar['clarid'] . '</a></td>';
+		if ( IS_JURY ) 
+			echo '<td>' . $link . $clar['clarid'] . '</a></td>';
+
+		echo '<td>' . $link;
+		echo printtime($clar['submittime']) . '</a></td>';
 
 		$sender = htmlspecialchars($clar['sender']);
 		$recipient = htmlspecialchars($clar['recipient']);
@@ -204,11 +212,39 @@ function putClarificationList($clars, $team = NULL)
 		}
 		echo "</a></td>";
 
-		echo '<td>' . $link;
-		echo printtime($clar['submittime']) . '</a></td>';
-		echo '<td>' . $link;
+		echo '<td class="clartext">' . $link;
 		echo summarizeClarification($clar['body']);
-		echo "</a></td></tr>\n";
+		echo "</a></td>";
+		if ( IS_JURY ) {
+			unset($answered, $jury_member);
+			$claim = FALSE;
+			$answered = printyn($clar['answered']);
+			if ( empty($clar['jury_member']) ) {
+				$jury_member = '&nbsp;';
+			} else {
+				$jury_member = htmlspecialchars($clar['jury_member']);
+			}
+			if ( !$clar['answered'] ) {
+				if ( empty($clar['jury_member']) ) {
+					$claim = TRUE;
+				} else {
+					$answered = 'claimed';
+				}
+			}
+
+			echo "<td>$link $answered</a></td><td>";
+			if ( $claim && isset($clar['sender']) ) {
+				echo "<a class=\"button\" href=\"clarification.php?claim=1&id=" . htmlspecialchars($clar['clarid']) . "\">claim</a>";
+			} else {
+				if ( !$clar['answered'] && $jury_member==getJuryMember() ) {
+					echo "<a class=\"button\" href=\"clarification.php?unclaim=1&id=" . htmlspecialchars($clar['clarid']) . "\">unclaim</a>";
+				} else {
+					echo "$link $jury_member</a>";
+				}
+			}
+			echo "</td>";
+		}
+		echo "</tr>\n";
 	}
 	echo "</tbody>\n</table>\n\n";
 }
@@ -298,7 +334,7 @@ function confirmClar() {
 
 	?>
 <tr>
-<td valign="top"><b><label for="bodytext">Text</label>:</b></td>
+<td><b><label for="bodytext">Text</label>:</b></td>
 <td><?php
 $body = "";
 if ( $respid ) {
