@@ -3,7 +3,7 @@
 /**
  * Common functions in jury interface
  *
- * $Id: common.jury.php 3248 2010-07-13 11:17:36Z werth $
+ * $Id: common.jury.php 3646 2011-09-22 07:30:44Z kink $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -59,8 +59,6 @@ function delLink($table, $field, $value)
  */
 function rejudgeForm($table, $id)
 {
-	require_once(LIBWWWDIR . '/forms.php');
-
 	$ret = addForm('rejudge.php') .
 		addHidden('table', $table) .
 		addHidden('id', $id);
@@ -215,59 +213,87 @@ function importZippedProblem($zip, $probid = NULL)
 		}
 	}
 
+	// submit reference solutions
+	if ( isset($ini_array['allow_submit']) && $ini_array['allow_submit'] ) {
+		// First find all submittable languages:
+		$langs = $DB->q('KEYVALUETABLE SELECT langid AS extension, langid AS langid FROM language
+		                 WHERE allow_submit = 1');
+
+		for ($j = 0; $j < $zip->numFiles; $j++) {
+			$filename = $zip->getNameIndex($j);
+			$extension = end(explode(".", $filename));
+			$langid = getLangID($extension);
+			if( !empty($langid) && isset($langs[$langid]) ) {
+				if ( !($tmpfname = mkstemps(TMPDIR."/ref_solution-XXXXXX",0)) ) {
+					error("Could not create temporary file.");
+				}
+				file_put_contents($tmpfname, $zip->getFromIndex($j));
+				if( filesize($tmpfname) <= SOURCESIZE*1024 ) {
+					submit_solution('domjudge', $probid, $langs[$langid], $tmpfname);
+				}
+				unlink($tmpfname);
+			}
+		}
+	}
+
 	// FIXME: insert PDF into database
 
 	return $probid;
 }
 
 /**
- * Reads verifier from POST variables, returns $default if nothing is set.
+ * Reads jury member from POST variables, COOKIE's, returns $default if nothing is set.
  */
-function getVerifier($default = null)
+function getJuryMember($default = null)
 {
-	$verifier = $default;
-	if ( ! empty($_POST['verifier_selected']) ) $verifier = $_POST['verifier_selected'];
-	if ( ! empty($_POST['verifier_typed']) )    $verifier = $_POST['verifier_typed'];
+	$jury_member = $default;
+	if ( ! empty($_COOKIE['domjudge_jury_member']) ) $jury_member = $_COOKIE['domjudge_jury_member'];
+	if ( ! empty($_POST['jury_member_selected']) ) $jury_member = $_POST['jury_member_selected'];
+	if ( ! empty($_POST['jury_member_typed']) )    $jury_member = $_POST['jury_member_typed'];
 
-	return $verifier;
+	if ( !headers_sent() ) setJuryMember($jury_member);
+	return $jury_member;
 }
 
 /**
- * Sets verifier in a cookie, only if a non-empty string is given.
+ * Sets jury member in a cookie, only if a non-empty string is given.
  */
-function setVerifier($verifier)
+function setJuryMember($jury_member)
 {
-	// Set cookie of last verifier, expiry defaults to end of session.
-	if (  !empty($verifier) && is_string($verifier) ) {
+	// Set cookie of jury_member, expiry defaults to end of session.
+	if ( !empty($jury_member) && is_string($jury_member) ) {
 		if  (version_compare(PHP_VERSION, '5.2') >= 0) {
 			// HTTPOnly Cookie, while this cookie is not security critical
 			// it's a good habit to get into.
-			setcookie('domjudge_lastverifier', $verifier, null, null, null, null, true);
+			setcookie('domjudge_jury_member', $jury_member, null, null, null, null, true);
 		} else {
-			setcookie('domjudge_lastverifier', $verifier);
+			setcookie('domjudge_jury_member', $jury_member);
 		}
 	}
 }
 
 /**
- * Add a both a text field and select box to select a verifier.
+ * Add a both a text field and select box to select a jury member.
  */
-function addVerifierSelect($default = null)
+function addJuryMemberSelect($default = null)
 {
 	global $DB;
 
-	$verifiers = $DB->q('COLUMN SELECT DISTINCT verifier FROM judging
-	                     WHERE verifier IS NOT NULL AND verifier != ""
-	                     ORDER BY verifier');
+	$jury_members = $DB->q('COLUMN SELECT DISTINCT jury_member FROM judging
+	                     WHERE jury_member IS NOT NULL AND jury_member != ""
+			     UNION
+			     SELECT DISTINCT jury_member FROM clarification
+			     WHERE jury_member IS NOT NULL AND jury_member != ""
+	                     ORDER BY jury_member');
 
  	if ( empty($default) ) $default = null;
-	if ( $default!==null && !in_array($default,$verifiers) ) $verifiers[] = $default;
+	if ( $default!==null && !in_array($default,$jury_members) ) $jury_members[] = $default;
 
-	$res = addInput('verifier_typed', '', 10, 15);
-	if ( count($verifiers) > 0 ) {
+	$res = addInput('jury_member_typed', '', 10, 15);
+	if ( count($jury_members) > 0 ) {
 		$opts = array(0 => "");
-		$opts = array_merge($verifiers, $opts);
-		$res .= ' or ' . addSelect('verifier_selected', $opts, $default);
+		$opts = array_merge($jury_members, $opts);
+		$res .= ' or ' . addSelect('jury_member_selected', $opts, $default);
 	}
 
 	return $res;
