@@ -1,6 +1,6 @@
 <?php
 /**
- * $Id: forms.php 3209 2010-06-12 00:13:43Z eldering $
+ * $Id: forms.php 3618 2011-08-24 21:53:40Z eldering $
  * Simple functions to start a form, add a field to a form, end a form.
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
@@ -72,6 +72,18 @@ function addInput($name, $value = '', $size = 0, $maxlength = 0) {
 	return addInputField('text', $name, $value, $attr);
 }
 
+/**
+ * Helper function for addSelect
+ */
+function matchSelect($val, $default)
+{
+	if ( is_array($default) ) {
+		return in_array($val, $default);
+	} else {
+		return $val==$default;
+	}
+}
+
 /**
  * Function to create a selectlist from an array.
  * Usage:
@@ -79,8 +91,9 @@ function addInput($name, $value = '', $size = 0, $maxlength = 0) {
  * values: array ( key => value )  ->  <option value="key">value</option>
  * default: the key that will be selected
  * usekeys: use the keys of the array as option value or not
+ * multi: multiple values are selectable, set to integer to set vertical size
  */
-function addSelect($name, $values, $default = null, $usekeys = false)
+function addSelect($name, $values, $default = null, $usekeys = false, $multi = false)
 {
 	// only one element
 	if ( count($values) == 1 ) {
@@ -89,12 +102,16 @@ function addSelect($name, $values, $default = null, $usekeys = false)
 			htmlspecialchars($v) . "\n";
 	}
 
-	$ret = '<select name="' . htmlspecialchars($name) .
-		'" id="' . htmlspecialchars(strtr($name,'[]','__')) . "\">\n";
+	$size = 5;
+	if ( is_int($multi) ) $size = $multi;
+
+	$ret = '<select name="' . htmlspecialchars($name) . '"' .
+		($multi ? " multiple=\"multiple\" size=\"$size\"" : '') .
+		' id="' . htmlspecialchars(strtr($name,'[]','__')) . "\">\n";
 	foreach ($values as $k => $v) {
 		if ( ! $usekeys ) $k = $v;
 		$ret .= '<option value="' .	htmlspecialchars( $k ) . '"' .
-			(($default == $k) ? ' selected="selected"' : '') . '>' .
+			( matchSelect($k, $default) ? ' selected="selected"' : '') . '>' .
 			htmlspecialchars($v) ."</option>\n";
 	}
 	$ret .= "</select>\n";
@@ -113,10 +130,10 @@ function addSubmit($value, $name = null, $onclick = null, $enable = true) {
 }
 /**
  * Form reset button, $value = caption
+ */
 function addReset($value) {
 	return addInputField('reset', null, $value);
 }
- */
 
 /**
  * Textarea form element.
@@ -131,7 +148,7 @@ function addTextArea($name, $text = '', $cols = 40, $rows = 10, $attr = '') {
 /**
  * Make a <form> start-tag.
  */
-function addForm($action, $method = 'post', $id = '', $enctype = '', $charset = '')
+function addForm($action, $method = 'post', $id = '', $enctype = '', $charset = '', $extra = '')
 {
 	if ( $id ) {
 		$id = ' id="'.$id.'"';
@@ -144,7 +161,7 @@ function addForm($action, $method = 'post', $id = '', $enctype = '', $charset =
 	}
 
 	return '<form action="'. $action .'" method="'. $method .'"'.
-		$enctype . $id . $charset . ">\n";
+		$enctype . $id . $charset . $extra .">\n";
 }
 
 /**
