@@ -3,7 +3,7 @@
  * Common page header.
  * Before including this, one can set $title, $refresh and $popup.
  *
- * $Id: header.php 3129 2010-02-23 20:44:05Z kink $
+ * $Id: header.php 3473 2010-12-01 10:01:32Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -12,7 +12,9 @@ if (!defined('DOMJUDGE_VERSION')) die("DOMJUDGE_VERSION not defined.");
 
 header('Content-Type: text/html; charset=' . DJ_CHARACTER_SET);
 
-if ( isset($refresh) ) {
+if ( isset($refresh) &&
+     (!isset($_COOKIE["domjudge_refresh"]) ||
+      (bool)$_COOKIE["domjudge_refresh"]) ) {
 	header('Refresh: ' . $refresh);
 }
 echo '<?xml version="1.0" encoding="' . DJ_CHARACTER_SET . '" ?>' . "\n";
@@ -52,8 +54,15 @@ if ( IS_JURY ) {
 if ($menu) {?>
 <script type="text/javascript" src="../js/domjudge.js"></script>
 </head>
-<body onload="setInterval('updateClarifications(\'<?php echo $ajaxtitle?>\')', 20000)">
-<?php include("menu.php");
+<?php
+if ( IS_JURY ) {
+	echo "<body onload=\"setInterval('updateClarifications(\'$ajaxtitle\')', 20000)\">\n";
+} else {
+	echo "<body>\n";
+}
+
+include("menu.php");
+
 } else {?>
 </head>
 <body>
