@@ -3,7 +3,7 @@
 /**
  * Functions for calculating the scoreboard.
  *
- * $Id: scoreboard.php 3209 2010-06-12 00:13:43Z eldering $
+ * $Id: scoreboard.php 3685 2011-10-11 15:22:37Z kink $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -44,8 +44,11 @@ function calcPenaltyTime($solved, $num_submissions)
 /**
  * Generate scoreboard data based on the cached data in table
  * 'scoreboard_{public,jury}'. If the function is called while
- * IS_JURY is defined, the scoreboard will always be current,
- * regardless of the freezetime setting in the contesttable.
+ * IS_JURY is defined or $jury set, the scoreboard will always be
+ * current, regardless of the freezetime setting in the contesttable.
+ *
+ * The $filter argument may contain subarrays 'affilid', 'country',
+ * 'categoryid' of values to filter on these.
  *
  * This function returns an array (scores, summary, matrix)
  * containing the following:
@@ -58,12 +61,14 @@ function calcPenaltyTime($solved, $num_submissions)
  * summary(num_correct, total_time, affils[affilid], countries[country], problems[probid])
  *    probid(num_submissions, num_correct, best_time)
  */
-function genScoreBoard($cdata) {
+function genScoreBoard($cdata, $jury = FALSE, $filter = NULL) {
 
 	global $DB;
 
 	$cid = $cdata['cid'];
 
+	if ( IS_JURY ) $jury = TRUE;
+
 	// Show final scores if contest is over and unfreezetime has been
 	// reached, or if contest is over and no freezetime had been set.
 	// We can compare $now and the dbfields stringwise.
@@ -76,7 +81,7 @@ function genScoreBoard($cdata) {
 	$cstarted = difftime($cdata['starttime'],$now) <= 0;
 
 	// Don't leak information before start of contest
-	if ( ! $cstarted && ! IS_JURY ) return;
+	if ( ! $cstarted && ! $jury ) return;
 
 	// get the teams and problems
 	$teams = $DB->q('KEYTABLE SELECT login AS ARRAYKEY, login, team.name,
@@ -85,8 +90,13 @@ function genScoreBoard($cdata) {
 	                 LEFT JOIN team_category
 	                        ON (team_category.categoryid = team.categoryid)
 	                 LEFT JOIN team_affiliation
-	                        ON (team_affiliation.affilid = team.affilid)' .
-	                ( IS_JURY ? '' : ' WHERE visible = 1' ) );
+	                        ON (team_affiliation.affilid = team.affilid)
+	                 WHERE TRUE' .
+	                ( $jury ? '' : ' AND visible = 1' ) .
+	                (isset($filter['affilid']) ? ' AND team.affilid IN (%As) ' : ' %_') .
+	                (isset($filter['country']) ? ' AND country IN (%As) ' : ' %_') .
+	                (isset($filter['categoryid']) ? ' AND team.categoryid IN (%As) ' : ' %_'),
+	                @$filter['affilid'], @$filter['country'], @$filter['categoryid']);
 
 	$probs = $DB->q('KEYTABLE SELECT probid AS ARRAYKEY, probid FROM problem
 	                 WHERE cid = %i AND allow_submit = 1
@@ -99,7 +109,7 @@ function genScoreBoard($cdata) {
 					 'problems' => array());
 
 	// scoreboard_jury is always up to date, scoreboard_public might be frozen.
-	if ( IS_JURY || $showfinal ) {
+	if ( $jury || $showfinal ) {
 		$cachetable = 'scoreboard_jury';
 	} else {
 		$cachetable = 'scoreboard_public';
@@ -216,14 +226,14 @@ function genScoreBoard($cdata) {
 	                        ON (team_category.categoryid = team.categoryid)
 	                 LEFT JOIN team_affiliation
 	                        ON (team_affiliation.affilid = team.affilid)' .
-	                ( IS_JURY ? '' : ' WHERE visible = 1' ) );
+	                ( $jury ? '' : ' WHERE visible = 1' ) );
 	$probs = $DB->q('KEYTABLE SELECT probid AS ARRAYKEY,
 	                 probid, name, color FROM problem
 	                 WHERE cid = %i AND allow_submit = 1
 	                 ORDER BY probid', $cid);
 	$categs = $DB->q('KEYTABLE SELECT categoryid AS ARRAYKEY,
  	                  categoryid, name, color FROM team_category ' .
-	                 (IS_JURY ? '' : 'WHERE visible = 1 ' ) .
+	                 ($jury ? '' : 'WHERE visible = 1 ' ) .
 	                 'ORDER BY sortorder,name,categoryid');
 
 	return array( 'matrix'     => $MATRIX,
@@ -236,14 +246,23 @@ function genScoreBoard($cdata) {
 
 /**
  * Output the general scoreboard based on the cached data in table
- * 'scoreboard'. $myteamid can be passed to highlight a specific row.
+ * 'scoreboard_{team,jury}'. $myteamid can be passed to highlight a
+ * specific row.
  * If this function is called while IS_JURY is defined, the scoreboard
  * will always be current, regardless of the freezetime setting in the
- * contesttable. $static generates output suitable for static html pages.
+ * contesttable.
+ * $static generates output suitable for standalone static html pages,
+ * that is without references/links to other parts of the DOMjudge
+ * interface.
+ * $limitteams is an array of teamid's whose rows will be the only
+ * ones displayed. The function still needs the complete scoreboard
+ * data or it will not know the rank.
+ * if $displayrank is false the first column will not display the
+ * team's current rank but a question mark.
  */
-function renderScoreBoard($cdata, $sdata, $myteamid = null, $static = FALSE) {
+function renderScoreBoardTable($cdata, $sdata, $myteamid = null,
+	$static = FALSE, $limitteams = null, $displayrank = TRUE, $center = FALSE) {
 
-	if ( empty( $cdata ) ) { echo "<p class=\"nodata\">No active contest</p>\n"; return; }
 	$cid = $cdata['cid'];
 
 	// 'unpack' the scoreboard data:
@@ -255,49 +274,10 @@ function renderScoreBoard($cdata, $sdata, $myteamid = null, $static = FALSE) {
 	$categs  = $sdata['categories'];
 	unset($sdata);
 
-	// Show final scores if contest is over and unfreezetime has been
-	// reached, or if contest is over and no freezetime had been set.
-	// We can compare $now and the dbfields stringwise.
-	$now = now();
-	$showfinal  = ( !isset($cdata['freezetime']) &&
-	                difftime($cdata['endtime'],$now) <= 0 ) ||
-	              ( isset($cdata['unfreezetime']) &&
-	                difftime($cdata['unfreezetime'], $now) <= 0 );
-	// freeze scoreboard if freeze time has been reached and
-	// we're not showing the final score yet
-	$showfrozen = !$showfinal && isset($cdata['freezetime']) &&
-	              difftime($cdata['freezetime'],$now) <= 0;
-	// contest is active but has not yet started
-	$cstarted = difftime($cdata['starttime'],$now) <= 0;
-
-	// page heading with contestname and start/endtimes
-	echo "<h1>Scoreboard " . htmlspecialchars($cdata['contestname']) . "</h1>\n\n";
-
-	if ( $showfinal ) {
-		echo "<h4>final standings</h4>\n\n";
-	} elseif ( ! $cstarted ) {
-		echo "<h4>scheduled to start at " . printtime($cdata['starttime']) . "</h4>\n\n";
-		// Stop here (do not leak problem number, descriptions etc).
-		// Alternatively we could only display the list of teams?
-		if ( ! IS_JURY ) return;
-	} else {
-		echo "<h4>starts: " . printtime($cdata['starttime']) .
-				" - ends: " . printtime($cdata['endtime']) ;
-
-		if ( $showfrozen ) {
-			echo " (";
-			if ( IS_JURY ) {
-				echo "public scoreboard is ";
-			}
-			echo "frozen since " . printtime($cdata['freezetime']) .")";
-		}
-		echo "</h4>\n\n";
-	}
-
 	// configuration
 	$SHOW_AFFILIATIONS = dbconfig_get('show_affiliations', 1);
 
-	echo '<table class="scoreboard' . (IS_JURY ? ' scoreboard_jury' : '') . "\">\n";
+	echo '<table class="scoreboard' . (IS_JURY ? ' scoreboard_jury' : '') . ($center ? ' center' : '') . "\">\n";
 
 	// output table column groups (for the styles)
 	echo '<colgroup><col id="scorerank" />' .
@@ -330,6 +310,8 @@ function renderScoreBoard($cdata, $sdata, $myteamid = null, $static = FALSE) {
 	// print the main scoreboard rows
 	$prevsortorder = -1;
 	foreach( $scores as $team => $totals ) {
+		// skip if we have limitteams and the team is not listed
+		if ( !empty($limitteams) && !in_array($team,$limitteams) ) continue;
 
 		// rank, team name, total correct, total time
 		echo '<tr';
@@ -347,7 +329,9 @@ function renderScoreBoard($cdata, $sdata, $myteamid = null, $static = FALSE) {
 		}
 		echo '><td class="scorepl">';
 		// Only print rank when score is different from the previous team
-		if ( !isset($prevteam) || $scores[$prevteam]['rank']!=$totals['rank'] ) {
+		if ( ! $displayrank ) {
+			echo jurylink(null,'?');
+		} elseif ( !isset($prevteam) || $scores[$prevteam]['rank']!=$totals['rank'] ) {
 			echo jurylink(null,$totals['rank']);
 		} else {
 			echo jurylink(null,'');
@@ -423,31 +407,36 @@ function renderScoreBoard($cdata, $sdata, $myteamid = null, $static = FALSE) {
 		}
 		echo "</tr>\n";
 	}
-	echo "</tbody>\n\n<tbody>\n";
+	echo "</tbody>\n\n";
 
-	// print a summaryline
-	echo '<tr id="scoresummary" title="#submitted / #correct / fastest time">' .
-		'<td title="total teams">' .
-		jurylink(null,count($teams)) . '</td>' .
-		( $SHOW_AFFILIATIONS ? '<td class="scoreaffil" title="#affiliations / #countries">' .
-		  jurylink('team_affiliations.php',count($summary['affils']) . ' / ' .
-				   count($summary['countries'])) . '</td>' : '' ) .
-		'<td title=" ">' . jurylink(null,'Summary') . '</td>' .
-		'<td title="total solved" class="scorenc">' . jurylink(null,$summary['num_correct'])  . '</td><td title=" "></td>';
+	if ( empty($limitteams) ) {
+		// print a summaryline
+		echo '<tbody><tr id="scoresummary" title="#submitted / #correct / fastest time">' .
+			'<td title="total teams">' .
+			jurylink(null,count($matrix)) . '</td>' .
+			( $SHOW_AFFILIATIONS ? '<td class="scoreaffil" title="#affiliations / #countries">' .
+			  jurylink('team_affiliations.php',count($summary['affils']) . ' / ' .
+					   count($summary['countries'])) . '</td>' : '' ) .
+			'<td title=" ">' . jurylink(null,'Summary') . '</td>' .
+			'<td title="total solved" class="scorenc">' . jurylink(null,$summary['num_correct'])  . '</td><td title=" "></td>';
 
-	foreach( array_keys($probs) as $prob ) {
-		$str = $summary['problems'][$prob]['num_submissions'] . ' / ' .
-		       $summary['problems'][$prob]['num_correct'] . ' / ' .
-			   ( isset($summary['problems'][$prob]['best_time']) ?
-				 $summary['problems'][$prob]['best_time'] : '-' );
-		echo '<td>' .
-			jurylink('problem.php?id=' . urlencode($prob),$str) .
-			'</td>';
+		foreach( array_keys($probs) as $prob ) {
+			$str = $summary['problems'][$prob]['num_submissions'] . ' / ' .
+			       $summary['problems'][$prob]['num_correct'] . ' / ' .
+				   ( isset($summary['problems'][$prob]['best_time']) ?
+					 $summary['problems'][$prob]['best_time'] : '-' );
+			echo '<td>' .
+				jurylink('problem.php?id=' . urlencode($prob),$str) .
+				'</td>';
+		}
+		echo "</tr>\n</tbody>\n";
+	
 	}
-	echo "</tr>\n</tbody>\n</table>\n\n";
+
+	echo "</table>\n\n";
 
 	// only print legend when there's more than one category
-	if ( count($categs) > 1 ) {
+	if ( empty($limitteams) && count($categs) > 1 ) {
 		echo "<p><br /><br /></p>\n<table id=\"legend\" class=\"scoreboard" .
 			(IS_JURY ? ' scoreboard_jury' : '') . "\">\n" .
 			"<thead><tr><th scope=\"col\">" .
@@ -463,9 +452,115 @@ function renderScoreBoard($cdata, $sdata, $myteamid = null, $static = FALSE) {
 		echo "</tbody>\n</table>\n\n";
 	}
 
+
+	return;
+}
+
+/**
+ * Function to output a complete scoreboard.
+ * This takes care of outputting the headings, start/endtimes and footer
+ * of the scoreboard. It calls genScoreBoard to generate the data and
+ * renderScoreBoardTable for displaying the actual table.
+ *
+ * Arguments:
+ * $cdata       current contest data, as from 'getCurContest(TRUE)'
+ * $myteamid    set to highlight that teamid in the scoreboard
+ * $static      generate a static scoreboard, e.g. for external use
+ * $filter      set to TRUE to generate filter options, or pass array
+ *              with keys 'affilid', 'country', 'categoryid' pointing
+ *              to array of values to filter on these.
+ */
+function putScoreBoard($cdata, $myteamid = NULL, $static = FALSE, $filter = FALSE)
+{
+	global $DB, $pagename;
+
+	if ( empty( $cdata ) ) { echo "<p class=\"nodata\">No active contest</p>\n"; return; }
+
+	$fdata = calcFreezeData($cdata);
+	$sdata = genScoreBoard($cdata, FALSE, $filter);
+
+	// page heading with contestname and start/endtimes
+	echo "<h1>Scoreboard " . htmlspecialchars($cdata['contestname']) . "</h1>\n\n";
+
+	if ( $fdata['showfinal'] ) {
+		echo "<h4>final standings</h4>\n\n";
+	} elseif ( ! $fdata['cstarted'] ) {
+		echo "<h4>scheduled to start at " . printtime($cdata['starttime']) . "</h4>\n\n";
+		// Stop here (do not leak problem number, descriptions etc).
+		// Alternatively we could only display the list of teams?
+		if ( ! IS_JURY ) return;
+	} else {
+		echo "<h4>starts: " . printtime($cdata['starttime']) .
+				" - ends: " . printtime($cdata['endtime']) ;
+
+		if ( $fdata['showfrozen'] ) {
+			echo " (";
+			if ( IS_JURY ) {
+				echo "public scoreboard is ";
+			}
+			echo "frozen since " . printtime($cdata['freezetime']) .")";
+		}
+		echo "</h4>\n\n";
+	}
+
+	if ( $filter!==FALSE ) {
+		
+		$affilids  = array();
+		$countries = array();
+		$categids  = array();
+		foreach( $sdata['teams'] as $team ) {
+			if ( !empty($team['affilid']) ) {
+				$affilids[]  = $team['affilid'];
+				$countries[] = $team['country'];
+			}
+			$categids[] = $team['categoryid'];
+		}
+
+		$countries = array_unique($countries);
+		sort($countries);
+
+		$affilids = empty($affilids) ? array() : 
+				$DB->q('KEYVALUETABLE SELECT affilid, name FROM team_affiliation
+		                    WHERE affilid IN (%As)', $affilids);
+		$categids = empty($categids) ? array() :
+				$DB->q('KEYVALUETABLE SELECT categoryid, name FROM team_category
+		                    WHERE categoryid IN (%As)', $categids);
+
+		if ( count($categids) > 1 || count($countries) > 1 || count($affilids) > 1 ) {
+
+			require_once(LIBWWWDIR . '/forms.php');
+
+		?>
+
+<table class="scorefilter">
+<tr>
+<td><a href="javascript:collapse('filter')"><img src="../images/filter.png" alt="filter&hellip;" title="filter&hellip;" class="picto" /></a></td>
+<td><div id="detailfilter">
+<?php
+
+		echo addForm($pagename, 'get') .
+			( count($affilids) > 1 ? addSelect('affilid[]',    $affilids,  @$filter['affilid'],    TRUE,  8) : "" ) .
+			( count($countries) > 1 ? addSelect('country[]',    $countries, @$filter['country'],    FALSE, 8) : "" ) .
+			( count($categids) > 1 ? addSelect('categoryid[]', $categids,  @$filter['categoryid'], TRUE,  8) : "" ) .
+			addSubmit('filter') . addSubmit('clear', 'clear') .
+			addEndForm();
+		?>
+</div></td></tr>
+</table>
+<script type="text/javascript" language="JavaScript">
+<!--
+collapse("filter");
+-->
+</script>
+		<?php
+		}
+	}
+
+	renderScoreBoardTable($cdata,$sdata,$myteamid,$static);
+
 	// last modified date, now if we are the jury, else include the
 	// freeze time
-	if( ! IS_JURY && $showfrozen ) {
+	if( ! IS_JURY && $fdata['showfrozen'] ) {
 		$lastupdate = strtotime($cdata['freezetime']);
 	} else {
 		$lastupdate = time();
@@ -477,100 +572,66 @@ function renderScoreBoard($cdata, $sdata, $myteamid = null, $static = FALSE) {
 }
 
 /**
- * Very simple wrapper around the scoreboard data-generating and
- * rendering functions.
+ * Given an array of contest data, calculates whether the contest
+ * has already started ('cstarted'), and if scoreboard is currently
+ * frozen ('showfrozen') or final ('showfinal').
  */
-function putScoreBoard($cdata, $myteamid = null, $static = FALSE) {
+function calcFreezeData($cdata)
+{
+	$fdata = array();
 
-	$sdata = genScoreBoard($cdata);
+	// Show final scores if contest is over and unfreezetime has been
+	// reached, or if contest is over and no freezetime had been set.
+	// We can compare $now and the dbfields stringwise.
+	$now = now();
+	$fdata['showfinal']  = ( !isset($cdata['freezetime']) &&
+	                difftime($cdata['endtime'],$now) <= 0 ) ||
+	              ( isset($cdata['unfreezetime']) &&
+	                difftime($cdata['unfreezetime'], $now) <= 0 );
+	// freeze scoreboard if freeze time has been reached and
+	// we're not showing the final score yet
+	$fdata['showfrozen'] = !$fdata['showfinal'] && isset($cdata['freezetime']) &&
+	              difftime($cdata['freezetime'],$now) <= 0;
+	// contest is active but has not yet started
+	$fdata['cstarted'] = difftime($cdata['starttime'],$now) <= 0;
 
-	renderScoreBoard($cdata,$sdata,$myteamid,$static);
+	return $fdata;
 }
 
 /**
  * Output a team row from the scoreboard based on the cached data in
  * table 'scoreboard'.
  */
-function putTeamRow($cdata, $teamid) {
+function putTeamRow($cdata, $teamids) {
 
-	global $DB;
+	if ( empty($cdata) ) return;
 
-	if ( empty( $cdata )  || difftime($cdata['starttime'],now()) > 0 ) return;
-	$cid = $cdata['cid'];
+	$fdata = calcFreezeData($cdata);
 
-	echo '<table class="scoreboard">' . "\n";
+	if ( ! $fdata['cstarted'] ) {
+		if ( ! IS_JURY ) {
 
-	$probs = $DB->q('KEYTABLE SELECT probid AS ARRAYKEY, probid, name, color
-	                 FROM problem WHERE cid = %i AND allow_submit = 1
-	                 ORDER BY probid', $cid);
-
-	// column headers
-	echo "<tr class=\"scoreheader\"><th>problem</th><th>score</th></tr>\n";
-
-	// initialize the arrays we'll build from the data
-	$MATRIX = array();
-
-	// for a team, we always display the "current" information, that is,
-	// from scoreboard_jury
-	$scoredata = $DB->q('SELECT * FROM scoreboard_jury WHERE cid = %i AND teamid = %s',
-	                    $cid, $teamid);
-
-	// loop all info the scoreboard cache and put it in our own datastructure
-	while ( $srow = $scoredata->next() ) {
-		// skip this row if the problem is not known by us
-		if ( ! array_key_exists ( $srow['probid'], $probs ) ) continue;
-
-		$penalty = calcPenaltyTime( $srow['is_correct'], $srow['submissions'] );
-
-		// fill our matrix with the scores from the database,
-		$MATRIX[$srow['probid']] = array (
-			'is_correct'      => (bool) $srow['is_correct'],
-			'num_submissions' => $srow['submissions'],
-			'time'            => $srow['totaltime'],
-			'penalty'         => $penalty );
+			global $teamdata;
+			echo "<h2 id=\"teamwelcome\">welcome team <span id=\"teamwelcometeam\">" .
+				htmlspecialchars($teamdata['name']) . "</span>!</h2>\n\n";
+			echo "<h3 id=\"contestnotstarted\">contest is scheduled to start at " .
+				printtime($cdata['starttime']) . "</h3>\n\n";
+		}
+		
+		return;
 	}
 
-	$SUMMARY = array('num_correct' => 0, 'total_time' => 0);
-	// for each problem
-	foreach ( $probs as $prob => $probdata ) {
-		// if we have scores, use them, else, provide the defaults
-		// (happens when nothing submitted for this problem,team yet)
-		if ( isset ( $MATRIX[$prob] ) ) {
-			$pdata = $MATRIX[$prob];
-		} else {
-			$pdata = array ( 'num_submissions' => 0, 'is_correct' => 0,
-			                 'time' => 0, 'penalty' => 0);
-		}
-		echo '<tr><td class="probid" title="' .
-			htmlspecialchars($probdata['name']) . '">' .
-			( !empty($probdata['color']) ?
-			  '<img style="background-color: ' . htmlspecialchars($probdata['color']) .
-			  ';" alt="problem colour ' . htmlspecialchars($probdata['color']) .
-			  '" src="../images/circle.png" /> ' : '' ) .
-			htmlspecialchars($prob) . '</td><td class="';
-		// CSS class for correct/incorrect/neutral results
-		if( $pdata['is_correct'] ) {
-			echo 'score_correct';
-		} elseif ( $pdata['num_submissions'] > 0 ) {
-			echo 'score_incorrect';
-		} else {
-			echo 'score_neutral';
-		}
-		// number of submissions for this problem
-		echo '">' . $pdata['num_submissions'];
-		// if correct, print time scored
-		if( $pdata['is_correct'] ) {
-			echo " (" . $pdata['time'] . ' + ' . $pdata['penalty'] . ")";
-			$SUMMARY['num_correct'] ++;
-			$SUMMARY['total_time'] += $pdata['time'] + $pdata['penalty'];
-		}
-		echo "</td></tr>\n";
-	}
+	// Calculate scoreboard as jury to display non-visible teams:
+	$sdata = genScoreBoard($cdata, TRUE);
 
-	echo "<tr id=\"scoresummary\" title=\"#correct / time\"><td>Summary</td>".
-		"<td>" . $SUMMARY['num_correct'] . " / " . $SUMMARY['total_time'] . "</td></tr>\n";
+	$myteamid = null;
+	$static = FALSE;
+	$displayrank = !$fdata['showfrozen'];
 
-	echo "</table>\n\n";
+	if ( ! IS_JURY ) echo "<div id=\"teamscoresummary\">\n";
+	renderScoreBoardTable($cdata,$sdata,$myteamid,$static,
+		$teamids,$displayrank,TRUE);
+	if ( ! IS_JURY ) echo "</div>\n\n";
 
 	return;
 }
