@@ -4,7 +4,7 @@
 -- database tables, but preferably use 'dj-setup-database'. Database
 -- should be set externally (e.g. to 'domjudge').
 --
--- $Id: mysql_db_structure.sql 3359 2010-08-19 19:25:17Z eldering $
+-- $Id: mysql_db_structure.sql 3594 2011-08-13 18:59:21Z eldering $
 
 /*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
 
@@ -19,12 +19,17 @@ CREATE TABLE `clarification` (
   `submittime` datetime NOT NULL COMMENT 'Time sent',
   `sender` varchar(15) default NULL COMMENT 'Team login, null means jury',
   `recipient` varchar(15) default NULL COMMENT 'Team login, null means to jury or to all',
+  `jury_member` varchar(15) default NULL COMMENT 'Name of jury member who answered this',
   `probid` varchar(8) default NULL COMMENT 'Problem associated to this clarification',
   `body` text NOT NULL COMMENT 'Clarification text',
   `answered` tinyint(1) unsigned NOT NULL default '0' COMMENT 'Has been answered by jury?',
   PRIMARY KEY  (`clarid`),
   KEY `cid` (`cid`,`answered`,`submittime`),
-  CONSTRAINT `clarification_ibfk_1` FOREIGN KEY (`cid`) REFERENCES `contest` (`cid`)
+  KEY `respid` (`respid`),
+  KEY `probid` (`probid`),
+  CONSTRAINT `clarification_ibfk_1` FOREIGN KEY (`cid`) REFERENCES `contest` (`cid`) ON DELETE CASCADE,
+  CONSTRAINT `clarification_ibfk_2` FOREIGN KEY (`respid`) REFERENCES `clarification` (`clarid`) ON DELETE SET NULL,
+  CONSTRAINT `clarification_ibfk_3` FOREIGN KEY (`probid`) REFERENCES `problem` (`probid`) ON DELETE SET NULL
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Clarification requests by teams and responses by the jury';
 
 --
@@ -50,6 +55,10 @@ CREATE TABLE `contest` (
   `freezetime` datetime default NULL COMMENT 'Time scoreboard is frozen',
   `endtime` datetime NOT NULL COMMENT 'Time after which no more submissions are accepted',
   `unfreezetime` datetime default NULL COMMENT 'Unfreeze a frozen scoreboard at this time',
+  `activatetime_string` varchar(20) NOT NULL COMMENT 'Time contest becomes visible in team/public views',
+  `freezetime_string` varchar(20) default NULL COMMENT 'Time scoreboard is frozen',
+  `endtime_string` varchar(20) NOT NULL COMMENT 'Time after which no more submissions are accepted',
+  `unfreezetime_string` varchar(20) default NULL COMMENT 'Unfreeze a frozen scoreboard at this time',
   `enabled` tinyint(1) unsigned NOT NULL default '1' COMMENT 'Whether this contest can be active',
   PRIMARY KEY (`cid`),
   KEY `cid` (`cid`,`enabled`)
@@ -94,19 +103,19 @@ CREATE TABLE `judging` (
   `submitid` int(4) unsigned NOT NULL COMMENT 'Submission ID being judged',
   `starttime` datetime NOT NULL COMMENT 'Time judging started',
   `endtime` datetime default NULL COMMENT 'Time judging ended, null = still busy',
-  `judgehost` varchar(50) NOT NULL COMMENT 'Judgehost that performed the judging',
+  `judgehost` varchar(50) default NULL COMMENT 'Judgehost that performed the judging',
   `result` varchar(25) default NULL COMMENT 'Result string as defined in config.php',
   `verified` tinyint(1) unsigned NOT NULL default '0' COMMENT 'Result verified by jury member?',
-  `verifier` varchar(15) NOT NULL default '' COMMENT 'Name of jury member who verified this',
+  `jury_member` varchar(15) default NULL COMMENT 'Name of jury member who verified this',
   `valid` tinyint(1) unsigned NOT NULL default '1' COMMENT 'Old judging is marked as invalid when rejudging',
   `output_compile` text COMMENT 'Output of the compiling the program',
   PRIMARY KEY  (`judgingid`),
   KEY `submitid` (`submitid`),
   KEY `judgehost` (`judgehost`),
   KEY `cid` (`cid`),
-  CONSTRAINT `judging_ibfk_1` FOREIGN KEY (`cid`) REFERENCES `contest` (`cid`),
-  CONSTRAINT `judging_ibfk_2` FOREIGN KEY (`submitid`) REFERENCES `submission` (`submitid`),
-  CONSTRAINT `judging_ibfk_3` FOREIGN KEY (`judgehost`) REFERENCES `judgehost` (`hostname`)
+  CONSTRAINT `judging_ibfk_1` FOREIGN KEY (`cid`) REFERENCES `contest` (`cid`) ON DELETE CASCADE,
+  CONSTRAINT `judging_ibfk_2` FOREIGN KEY (`submitid`) REFERENCES `submission` (`submitid`) ON DELETE CASCADE,
+  CONSTRAINT `judging_ibfk_3` FOREIGN KEY (`judgehost`) REFERENCES `judgehost` (`hostname`) ON DELETE SET NULL
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Result of judging a submission';
 
 --
@@ -123,7 +132,11 @@ CREATE TABLE `judging_run` (
   `output_diff` text COMMENT 'Diffing the program output and testcase output',
   `output_error` text COMMENT 'Standard error output of the program',
   PRIMARY KEY  (`runid`),
-  UNIQUE KEY `testcaseid` (`judgingid`, `testcaseid`)
+  UNIQUE KEY `testcaseid` (`judgingid`, `testcaseid`),
+  KEY `judgingid` (`judgingid`),
+  KEY `testcaseid_2` (`testcaseid`),
+  CONSTRAINT `judging_run_ibfk_1` FOREIGN KEY (`testcaseid`) REFERENCES `testcase` (`testcaseid`),
+  CONSTRAINT `judging_run_ibfk_2` FOREIGN KEY (`judgingid`) REFERENCES `judging` (`judgingid`) ON DELETE CASCADE
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Result of a testcase run within a judging';
 
 --
@@ -131,14 +144,12 @@ CREATE TABLE `judging_run` (
 --
 
 CREATE TABLE `language` (
-  `langid` varchar(8) NOT NULL COMMENT 'Unique ID (string)',
+  `langid` varchar(8) NOT NULL COMMENT 'Unique ID (string), used for source file extension',
   `name` varchar(255) NOT NULL COMMENT 'Descriptive language name',
-  `extension` varchar(5) NOT NULL COMMENT 'Filename extension for this language',
   `allow_submit` tinyint(1) unsigned NOT NULL default '1' COMMENT 'Are submissions accepted in this language?',
   `allow_judge` tinyint(1) unsigned NOT NULL default '1' COMMENT 'Are submissions in this language judged?',
   `time_factor` float NOT NULL default '1' COMMENT 'Language-specific factor multiplied by problem run times',
-  PRIMARY KEY  (`langid`),
-  UNIQUE KEY `extension` (`extension`)
+  PRIMARY KEY  (`langid`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Programming languages in which teams can submit solutions';
 
 --
@@ -157,7 +168,7 @@ CREATE TABLE `problem` (
   `color` varchar(25) default NULL COMMENT 'Balloon colour to display on the scoreboard',
   PRIMARY KEY  (`probid`),
   KEY `cid` (`cid`),
-  CONSTRAINT `problem_ibfk_1` FOREIGN KEY (`cid`) REFERENCES `contest` (`cid`)
+  CONSTRAINT `problem_ibfk_1` FOREIGN KEY (`cid`) REFERENCES `contest` (`cid`) ON DELETE CASCADE
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Problems the teams can submit solutions for';
 
 --
@@ -212,11 +223,11 @@ CREATE TABLE `submission` (
   KEY `probid` (`probid`),
   KEY `langid` (`langid`),
   KEY `judgehost_2` (`judgehost`),
-  CONSTRAINT `submission_ibfk_1` FOREIGN KEY (`cid`) REFERENCES `contest` (`cid`),
-  CONSTRAINT `submission_ibfk_2` FOREIGN KEY (`teamid`) REFERENCES `team` (`login`),
-  CONSTRAINT `submission_ibfk_3` FOREIGN KEY (`probid`) REFERENCES `problem` (`probid`),
-  CONSTRAINT `submission_ibfk_4` FOREIGN KEY (`langid`) REFERENCES `language` (`langid`),
-  CONSTRAINT `submission_ibfk_5` FOREIGN KEY (`judgehost`) REFERENCES `judgehost` (`hostname`)
+  CONSTRAINT `submission_ibfk_1` FOREIGN KEY (`cid`) REFERENCES `contest` (`cid`) ON DELETE CASCADE,
+  CONSTRAINT `submission_ibfk_2` FOREIGN KEY (`teamid`) REFERENCES `team` (`login`) ON DELETE CASCADE,
+  CONSTRAINT `submission_ibfk_3` FOREIGN KEY (`probid`) REFERENCES `problem` (`probid`) ON DELETE CASCADE,
+  CONSTRAINT `submission_ibfk_4` FOREIGN KEY (`langid`) REFERENCES `language` (`langid`) ON DELETE CASCADE,
+  CONSTRAINT `submission_ibfk_5` FOREIGN KEY (`judgehost`) REFERENCES `judgehost` (`hostname`) ON DELETE SET NULL
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='All incoming submissions';
 
 --
@@ -238,8 +249,8 @@ CREATE TABLE `team` (
   UNIQUE KEY `name` (`name`),
   KEY `affilid` (`affilid`),
   KEY `categoryid` (`categoryid`),
-  CONSTRAINT `team_ibfk_1` FOREIGN KEY (`categoryid`) REFERENCES `team_category` (`categoryid`),
-  CONSTRAINT `team_ibfk_2` FOREIGN KEY (`affilid`) REFERENCES `team_affiliation` (`affilid`)
+  CONSTRAINT `team_ibfk_1` FOREIGN KEY (`categoryid`) REFERENCES `team_category` (`categoryid`) ON DELETE CASCADE,
+  CONSTRAINT `team_ibfk_2` FOREIGN KEY (`affilid`) REFERENCES `team_affiliation` (`affilid`) ON DELETE SET NULL
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='All teams participating in the contest';
 
 --
@@ -276,8 +287,10 @@ CREATE TABLE `team_unread` (
   `teamid` varchar(15) NOT NULL default '' COMMENT 'Team login',
   `mesgid` int(4) unsigned NOT NULL default '0' COMMENT 'Clarification ID',
   `type` varchar(25) NOT NULL default 'clarification' COMMENT 'Type of message (now always "clarification")',
-  PRIMARY KEY  (`teamid`,`type`,`mesgid`),
-  CONSTRAINT `team_unread_ibfk_1` FOREIGN KEY (`teamid`) REFERENCES `team` (`login`) ON DELETE CASCADE
+  PRIMARY KEY (`teamid`,`type`,`mesgid`),
+  KEY `mesgid` (`mesgid`),
+  CONSTRAINT `team_unread_ibfk_1` FOREIGN KEY (`teamid`) REFERENCES `team` (`login`) ON DELETE CASCADE,
+  CONSTRAINT `team_unread_ibfk_2` FOREIGN KEY (`mesgid`) REFERENCES `clarification` (`clarid`) ON DELETE CASCADE
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='List of items a team has not viewed yet';
 
 --
