@@ -4,7 +4,7 @@
 -- permissions, but preferably use 'dj-setup-database'. Database
 -- should be set externally (e.g. to 'domjudge').
 --
--- $Id: mysql_privileges.sql 3388 2010-10-24 13:01:24Z eldering $
+-- $Id: mysql_privileges.sql 3669 2011-10-10 15:29:57Z werth $
 
 
 -- Juryaccount can do anything to the data (but not modify the structure)
@@ -29,9 +29,9 @@ GRANT SELECT ON team_unread       TO `domjudge_team`;
 GRANT SELECT (judgingid, submitid, result, valid)        ON judging    TO `domjudge_public`, `domjudge_plugin`;
 GRANT SELECT (probid, name, cid, allow_submit, color)    ON problem    TO `domjudge_public`, `domjudge_plugin`;
 GRANT SELECT (submitid, cid, langid, probid, teamid,
-              submittime)                                ON submission TO `domjudge_public`, `domjudge_plugin`;
+              submittime, valid)                         ON submission TO `domjudge_public`, `domjudge_plugin`;
 
-GRANT SELECT (langid, name, extension, allow_submit)     ON language   TO `domjudge_team`, `domjudge_plugin`;
+GRANT SELECT (langid, name, allow_submit)                ON language   TO `domjudge_team`, `domjudge_plugin`;
 GRANT SELECT (probid, name, cid, allow_submit, color)    ON problem    TO `domjudge_team`;
 
 -- Team write privileges
