@@ -3,16 +3,16 @@
  *
  * Based on submit.pl by Eelco Dolstra.
  *  
- * $Id: submit.cc 3228 2010-07-05 22:34:43Z eldering $
+ * $Id: submit.cc 3569 2011-07-17 17:35:31Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
  *
  */
 
-#include "../etc/config.h"
+#include "config.h"
 
-#include "../etc/submit-config.h"
+#include "submit-config.h"
 
 /* Check whether default submission method is available; bail out if not */
 #if ( SUBMIT_DEFAULT == 1 ) && ( SUBMIT_ENABLE_CMD != 1 )
@@ -32,16 +32,12 @@
 #error "Webinterface submission requested, but libcURL not available."
 #endif
 
-/* Make sure we don't log to syslog */
-#undef SYSLOG
-
 /* Standard include headers */
 #include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <errno.h>
-#include <syslog.h>
 #include <string.h>
 #include <sys/wait.h>
 #include <sys/types.h>
@@ -62,11 +58,11 @@
 #endif
 
 /* C++ includes for easy string handling */
-using namespace std;
 #include <iostream>
 #include <sstream>
 #include <string>
 #include <vector>
+using namespace std;
 
 /* These defines are needed in 'version' and 'logmsg' */
 #define DOMJUDGE_PROGRAM "DOMjudge/" DOMJUDGE_VERSION
@@ -83,12 +79,10 @@ using namespace std;
 #include "basename.h"
 
 /* Common send/receive functions */
-#include "submitcommon.h"
+#include "submitcommon.hxx"
 
 const int timeout_secs = 60; /* seconds before send/receive timeouts with an error */
 
-extern int errno;
-
 /* Variables defining logmessages verbosity to stderr/logfile */
 extern int verbose;
 extern int loglevel;
@@ -580,7 +574,7 @@ magicerror:
 int cmdsubmit()
 {
 	int redir_fd[3];
-	char *args[MAXARGS];
+	char *args[2];
 	struct timeval timeout;
 	struct addrinfo hints;
 	char *port_str;
@@ -597,7 +591,7 @@ int cmdsubmit()
 	/* Construct copy command and execute it */
 	args[0] = filename;
 	args[1] = tempfile;
-	redir_fd[0] = redir_fd[1] = redir_fd[2] = 0;
+	redir_fd[0] = redir_fd[1] = redir_fd[2] = FDREDIR_NONE;
 	if ( execute(COPY_CMD,args,2,redir_fd,1)!=0 ) {
 		error(0,"cannot copy `%s' to `%s'",filename,tempfile);
 	}
@@ -749,7 +743,8 @@ int websubmit()
 	/* Fill post form */
 	curlformadd(COPYNAME,"code",   FILE,        filename);
 	curlformadd(COPYNAME,"probid", COPYCONTENTS,problem.c_str());
-	curlformadd(COPYNAME,"langext",COPYCONTENTS,extension.c_str());
+	curlformadd(COPYNAME,"langid", COPYCONTENTS,extension.c_str());
+	curlformadd(COPYNAME,"noninteractive",COPYCONTENTS,"1");
 	curlformadd(COPYNAME,"submit", COPYCONTENTS,"submit");
 
 	/* Set options for post */
