@@ -1,13 +1,15 @@
 /*
  * Common socket send/receive code for submit and submitdaemon programs.
  *
- * $Id: submitcommon.cc 3209 2010-06-12 00:13:43Z eldering $
+ * $Id: submitcommon.cc 3318 2010-08-14 10:13:49Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
  */
 
-#include "submitcommon.h"
+#include "config.h"
+
+#include "submitcommon.hxx"
 
 #include "lib.error.h"
 
