@@ -1,4 +1,4 @@
-/* $Id: test-fill-stderr.cpp 3302 2010-08-09 18:39:20Z eldering $
+/* $Id: test-fill-stderr.cpp 3602 2011-08-17 12:57:40Z eldering $
  *
  * Floods stderr and should fail with TIME-LIMIT or RUN-ERROR
  * depending on whether timelimit or filesize limit is reached first.
@@ -6,14 +6,12 @@
  * @EXPECTED_RESULTS@: TIME-LIMIT,RUN-ERROR
  */
 
-using namespace std;
-
 #include <iostream>
 #include <string>
 
 int main()
 {
-	while ( 1 ) cerr << "Fill stderr with nonsense, to test filesystem stability.\n";
+	while ( 1 ) std::cerr << "Fill stderr with nonsense, to test filesystem stability.\n";
 
 	return 0;
 }
