@@ -1,4 +1,4 @@
-/* $Id: test-float.cc 3302 2010-08-09 18:39:20Z eldering $
+/* $Id: test-float.cc 3602 2011-08-17 12:57:40Z eldering $
  *
  * This should fail with WRONG-ANSWER (C++ doesn't give floating point
  * errors when dividing by zero).
@@ -6,8 +6,6 @@
  * @EXPECTED_RESULTS@: WRONG-ANSWER
  */
 
-using namespace std;
-
 #include <vector>
 #include <stdio.h>
 #include <math.h>
@@ -17,7 +15,7 @@ int main()
 	double a = M_PI/2;
 	double b;
 
-	vector<int> c(10);
+	std::vector<int> c(10);
 
 	b = tan(a);
 	a = exp(b);
