@@ -4,7 +4,7 @@
  * permissions and the like. At the moment this only contains some basic
  * checks but this can be extended in the future.
  *
- * $Id: checkconfig.php 3209 2010-06-12 00:13:43Z eldering $
+ * $Id: checkconfig.php 3685 2011-10-11 15:22:37Z kink $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -19,18 +19,6 @@ requireAdmin();
 $time_start = microtime(TRUE);
 
 ?>
-<script type="text/javascript" language="JavaScript">
-<!--
-function collapse(x){
-  var oTemp=document.getElementById("detail"+x) ;
-  if (oTemp.style.display=="none") {
-    oTemp.style.display="block";
-  } else {
-    oTemp.style.display="none";
-  }
-}
-// -->
-</script>
 
 <h1>Config Checker</h1>
 
@@ -163,6 +151,15 @@ if ( $highlighter == 'native' ) {
 			htmlspecialchars($highlighter) .'".');
 }
 
+if ( class_exists("ZipArchive") ) {
+	result('software', 'Problem upload via zip bundles',
+	       'O', 'PHP ZipArchive class available for uploading problem data.');
+} else {
+	result('software', 'Problem upload via zip bundles',
+	       'W', 'Optionally, enable the PHP zip extension ' .
+	       'to be able to upload problem data via zip bundles.');
+}
+
 $mysqldatares = $DB->q('SHOW variables WHERE
                         Variable_name = "max_connections" OR
                         Variable_name = "version"');
@@ -456,6 +453,14 @@ while($row = $res->next()) {
 		$row['result'] . "\"\n";
 }
 
+// check for valid judgings that are already running too long
+$res = $DB->q('SELECT judgingid, submitid, starttime
+               FROM judging WHERE valid = 1 AND endtime IS NULL AND
+               (UNIX_TIMESTAMP()-UNIX_TIMESTAMP(starttime)) > 300');
+while($row = $res->next()) {
+	$details .= 'Judging s' . (int)$row['submitid'] . '/j' . (int)$row['judgingid'] .
+		" is running for longer than 5 minutes, probably the judgedaemon crashed\n";
+}
 
 // check for start/endtime problems and contestids
 $res = $DB->q('SELECT s.submitid AS s_submitid, j.submitid AS j_submitid,
@@ -500,8 +505,10 @@ foreach ( $RELATIONS as $table => $foreign_keys ) {
 	}
 	$res = $DB->q('SELECT * FROM ' . $table . ' ORDER BY ' . implode(',', $KEYS[$table]));
 	while ( $row = $res->next() ) {
-		foreach ( $foreign_keys as $foreign_key => $target ) {
-			if ( empty($row[$foreign_key]) ) {
+		foreach ( $foreign_keys as $foreign_key => $val ) {
+			@list( $target, $action ) = explode('&', $val);
+			if ( empty($action) ) $action = 'CASCADE';
+			if ( empty($row[$foreign_key]) || $action=='NOCONSTRAINT' ) {
 				continue;
 			}
 			$f = explode('.', $target);
