@@ -3,7 +3,7 @@
  * Show clarification thread and reply box.
  * When no id is given, show general clarification box.
  *
- * $Id: clarification.php 3209 2010-06-12 00:13:43Z eldering $
+ * $Id: clarification.php 3487 2010-12-05 12:17:52Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -25,9 +25,35 @@ if ( isset($_REQUEST['id']) ) {
 	$respid = (int) (empty($req['respid']) ? $id : $req['respid']);
 	$isgeneral = FALSE;
 } else {
+	$respid = NULL;
 	$isgeneral = TRUE;
 }
 
+$jury_member = getJuryMember();
+
+if ( isset($_REQUEST['claim']) || isset($_REQUEST['unclaim']) ) {
+
+	// Send headers now: after cookies, before possible warning messages.
+	if ( !isset($_REQUEST['unclaim']) ) require_once(LIBWWWDIR . '/header.php');
+
+	if ( $req['answered'] ) {
+		warning("Cannot claim this clarification: clarification already answered.");
+	} else if ( empty($jury_member) && isset($_REQUEST['claim']) ) {
+		warning("Cannot claim this clarification: no jury_member specified.");
+	} else {
+		if ( !empty($req['jury_member']) && isset($_REQUEST['claim']) ) {
+			warning("Submission claimed and previous owner " .
+			        @$req['jury_member'] . " replaced.");
+		}
+		$req['jury_member'] = $jury_member;
+		$DB->q('UPDATE clarification SET jury_member = ' .
+		       (isset($_REQUEST['unclaim']) ? 'NULL %_ ' : '%s ') .
+		       'WHERE clarid = %i', $jury_member, $id);
+
+		if ( isset($_REQUEST['unclaim']) ) header('Location: clarifications.php');
+	}
+}
+
 // insert a new response (if posted)
 if ( isset($_POST['submit']) && !empty($_POST['bodytext']) ) {
 
@@ -45,23 +71,20 @@ if ( isset($_POST['submit']) && !empty($_POST['bodytext']) ) {
 		$sendto = $_POST['sendto'];
 	}
 
-	if ( $isgeneral ) {
-		$newid = $DB->q('RETURNID INSERT INTO clarification
-		                 (cid, submittime, recipient, probid, body)
-		                 VALUES (%i, %s, %s, %s, %s)',
-		                $cid, now(), $sendto,
-		                ($_POST['problem'] == 'general' ? NULL : $_POST['problem']),
-		                $_POST['bodytext']);
-	} else {
-		$newid = $DB->q('RETURNID INSERT INTO clarification
-		                 (cid, respid, submittime, recipient, probid, body)
-		                 VALUES (%i, %i, %s, %s, %s, %s)',
-		                $cid, $respid, now(), $sendto,
-		                ($_POST['problem'] == 'general' ? NULL : $_POST['problem']),
-		                $_POST['bodytext']);
-	}
+	$newid = $DB->q('RETURNID INSERT INTO clarification
+	                 (cid, respid, submittime, recipient, probid, body,
+ 	                  answered, jury_member)
+	                 VALUES (%i, ' .
+	                ($respid===NULL ? 'NULL %_' : '%i') . ', %s, %s, %s, %s, %i, ' .
+	                (isset($jury_member) ? '%s)' : 'NULL %_)'),
+	                $cid, $respid, now(), $sendto,
+	                ($_POST['problem'] == 'general' ? NULL : $_POST['problem']),
+	                $_POST['bodytext'], 1, $jury_member);
+
 	if ( ! $isgeneral ) {
-		$DB->q('UPDATE clarification SET answered = 1 WHERE clarid = %i', $respid);
+		$DB->q('UPDATE clarification SET answered = 1, jury_member = ' .
+		       (isset($jury_member) ? '%s' : 'NULL %_') . ' WHERE clarid = %i',
+		       $jury_member, $respid);
 	}
 
 	if( is_null($sendto) ) {
@@ -93,15 +116,17 @@ if ( isset($_POST['submit']) && !empty($_POST['bodytext']) ) {
 
 // (un)set 'answered' (if posted)
 if ( isset($_POST['submit']) && isset($_POST['answered']) ) {
-	$DB->q('UPDATE clarification SET answered = %i WHERE clarid = %i',
-	       (int)$_POST['answered'], $respid);
+	$answered = (int)$_POST['answered'];
+	$DB->q('UPDATE clarification SET answered = %i, jury_member = ' .
+	       ($answered ? '%s ' : 'NULL %_ ') . 'WHERE clarid = %i',
+	       $answered, $jury_member, $respid);
 
 	// redirect back to the original location
 	header('Location: clarification.php?id=' . $id);
 	exit;
 }
 
-require(LIBWWWDIR . '/header.php');
+require_once(LIBWWWDIR . '/header.php');
 require(LIBWWWDIR . '/clarification.php');
 
 if ( ! $isgeneral ) {
@@ -109,6 +134,22 @@ if ( ! $isgeneral ) {
 // display clarification thread
 echo "<h1>Clarification $id</h1>\n\n";
 
+$pagename = basename($_SERVER['PHP_SELF']);
+if ( !$req['answered'] ) {
+	echo addForm($pagename . '?id=' . urlencode($id));
+
+	echo "<p>Claimed: " .
+	    "<strong>" . printyn(!empty($req['jury_member'])) . "</strong>";
+	if ( empty($req['jury_member']) ) {
+		echo '; ';
+	} else {
+		echo ', by ' . htmlspecialchars($req['jury_member']) . '; ' .
+		    addSubmit('unclaim', 'unclaim') . ' or ';
+	}
+	echo addSubmit('claim', 'claim') . ' as ' . addJuryMemberSelect($jury_member) .
+	    addEndForm();
+}
+
 if ( ! empty ( $req['respid'] ) ) {
 	$orig = $DB->q('MAYBETUPLE SELECT q.*, t.name AS name FROM clarification q
 	                LEFT JOIN team t ON (t.login = q.sender)
@@ -128,8 +169,6 @@ putClarification($id, NULL);
 // Display button to (un)set request as 'answered'
 // Not relevant for 'general clarifications', ie those with sender=null
 if ( !empty($req['sender']) ) {
-	require_once(LIBWWWDIR . '/forms.php');
-
 	echo addForm('clarification.php') .
 		addHidden('id', $id) .
 		addHidden('answered', !$req['answered']) .
