@@ -2,7 +2,7 @@
 /**
  * Clarifications overview
  *
- * $Id: clarifications.php 3149 2010-02-27 12:32:04Z kink $
+ * $Id: clarifications.php 3487 2010-12-05 12:17:52Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -12,11 +12,19 @@ require('init.php');
 $ajaxtitle = 'Clarification Requests';
 $title = $ajaxtitle.($nunread_clars ? ' ('.$nunread_clars.' new)' : '');
 
+$jury_member = getJuryMember();
+
 require(LIBWWWDIR . '/header.php');
 require(LIBWWWDIR . '/clarification.php');
 
 echo "<h1>Clarifications</h1>\n\n";
 
+echo addForm('clarifications.php') .
+	'<p>Claim submissions/clarifications as ' .
+	addJuryMemberSelect($jury_member) .
+	addSubmit('change') . "</p>" .
+	addEndForm() . "\n";
+
 echo "<p><a href=\"clarification.php\">Send Clarification</a></p>\n";
 echo "<p><a href=\"#newrequests\">View New Clarification Requests</a></p>\n";
 echo "<p><a href=\"#oldrequests\">View Old Clarification Requests</a></p>\n";
