@@ -2,7 +2,7 @@
 /**
  * View current, past and future contests
  *
- * $Id: contests.php 3209 2010-06-12 00:13:43Z eldering $
+ * $Id: contests.php 3652 2011-10-08 09:57:29Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -19,7 +19,20 @@ if ( isset($_POST['unfreeze']) ) {
 	if ( $docid != $cid ) {
 		error("Can only unfreeze for current contest");
 	}
-	$DB->q('UPDATE contest SET unfreezetime = %s WHERE cid = %i', now(), $docid);
+	$DB->q('UPDATE contest SET unfreezetime = %s, unfreezetime_string = %s
+	        WHERE cid = %i', now(), now(), $docid);
+}
+
+if ( isset($_GET['edited']) ) {
+
+	echo addForm('refresh_cache.php', 'get') .
+            msgbox (
+                "Warning: Refresh scoreboard cache",
+		"After changing contest times, it may be necessary to recalculate the cached scoreboards.<br /><br />" .
+		addSubmit('recalculate caches now') 
+		) .
+		addEndForm();
+
 }
 
 // Get data. Starttime seems most logical sort criterion.
