@@ -6,7 +6,7 @@
  *  - Does not support checkboxes yet, since these
  *    return no value when not checked.
  *
- * $Id: edit.php 3125 2010-02-23 19:14:54Z kink $
+ * $Id: edit.php 3328 2010-08-14 11:35:23Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -95,7 +95,7 @@ header('Location: '.$returnto);
  */
 function check_sane_keys($itemdata) {
 	foreach(array_keys($itemdata) as $key) {
-		if ( ! preg_match ('/^\w+$/', $key ) ) {
+		if ( ! preg_match ('/^' . IDENTIFIER_CHARS . '+$/', $key ) ) {
 			error ("Invalid characters in field name \"$key\".");
 		}
 	}
