@@ -2,7 +2,7 @@
 /**
  * Edit source code and resubmit to the database.
  *
- * $Id: edit_source.php 3577 2011-07-30 20:00:45Z eldering $
+ * $Id: edit_source.php 3569 2011-07-17 17:35:31Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -18,7 +18,7 @@ if ( isset($_POST['submitter']) ) {
 
 	file_put_contents($tmpfname, $_POST['source']);
 
-	submit_solution($_POST['submitter'], $_POST['probid'], $_POST['langext'], $tmpfname);
+	submit_solution($_POST['submitter'], $_POST['probid'], $_POST['langid'], $tmpfname);
 	unlink($tmpfname);
 
 	header('Location: submissions.php');
@@ -33,11 +33,10 @@ $source = $DB->q('MAYBETUPLE SELECT * FROM submission
 if ( empty($source) ) error ("Submission $id not found");
 
 $sourcefile = getSourceFilename($source['cid'],$id,$source['teamid'],
-                                $source['probid'],$source['extension']);
+                                $source['probid'],$source['langid']);
 
 $title = 'Source: ' . htmlspecialchars($sourcefile);
 require(LIBWWWDIR . '/header.php');
-require(LIBWWWDIR . '/forms.php');
 
 echo '<h2 class="filename"><a name="source"></a>Submission ' .
 	"<a href=\"submission.php?id=$id\">s$id</a> source: " .
@@ -48,11 +47,11 @@ echo addTextArea('source', $source['sourcecode'], 120, 40) . "<br />\n";
 
 $probs = $DB->q('KEYVALUETABLE SELECT probid, name FROM problem WHERE
                  allow_submit = 1 AND cid = %i ORDER BY name', $cid);
-$langs = $DB->q('KEYVALUETABLE SELECT extension, name FROM language WHERE
+$langs = $DB->q('KEYVALUETABLE SELECT langid, name FROM language WHERE
                  allow_submit = 1 ORDER BY name');
 
 echo addSelect('probid', $probs, $source['probid'], true);
-echo addSelect('langext', $langs, $source['extension'], true);
+echo addSelect('langid', $langs, $source['langid'], true);
 
 echo addHidden('teamid', $source['teamid']);
 echo addHidden('submitter', 'domjudge');
