@@ -2,7 +2,7 @@
 /**
  * Include required files.
  *
- * $Id: init.php 3146 2010-02-27 10:55:28Z eldering $
+ * $Id: init.php 3575 2011-07-30 11:28:24Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -27,11 +27,14 @@ require_once(LIBDIR . '/lib.misc.php');
 require_once(LIBDIR . '/lib.dbconfig.php');
 require_once(LIBDIR . '/use_db.php');
 
+parseLangExts();
+
 set_exception_handler('exception_handler');
 setup_database_connection('jury');
 
 require_once(LIBWWWDIR . '/common.php');
 require_once(LIBWWWDIR . '/print.php');
+require_once(LIBWWWDIR . '/forms.php');
 
 require_once(LIBWWWDIR . '/validate.jury.php');
 require_once(LIBWWWDIR . '/common.jury.php');
