@@ -2,7 +2,7 @@
 /**
  * View judgehost details
  *
- * $Id: judgehost.php 3209 2010-06-12 00:13:43Z eldering $
+ * $Id: judgehost.php 3602 2011-08-17 12:57:40Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -57,8 +57,6 @@ if ( empty($row['polltime']) ) {
 
 <?php
 if ( IS_ADMIN ) {
-	require_once(LIBWWWDIR . '/forms.php');
-
 	$cmd = ($row['active'] == 1 ? 'deactivate' : 'activate');
 
 	echo addForm('judgehost.php') . "<p>\n" .
@@ -88,23 +86,31 @@ if( $res->count() == 0 ) {
 	echo "<p class=\"nodata\">No judgings.</p>\n\n";
 } else {
 	echo "<table class=\"list sortable\">\n<thead>\n" .
-	     "<tr><th scope=\"col\">ID</th><th scope=\"col\">start</th>" .
-		 "<th scope=\"col\">end</th><th scope=\"col\">result</th>" .
+	     "<tr><th scope=\"col\">ID</th><th scope=\"col\">started</th>" .
+		 "<th scope=\"col\">runtime</th><th scope=\"col\">result</th>" .
 		 "<th scope=\"col\">valid</th><th scope=\"col\">verified</th>" .
 	     "</tr>\n</thead>\n<tbody>\n";
 
 	while( $jud = $res->next() ) {
-		$link = 'submission.php?id=' . (int)$jud['submitid'] .
-			'&amp;jid=' . (int)$jud['judgingid'];
+		$start = strtotime($jud['starttime']);
+		if ( empty($jud['endtime']) ) {
+			if ( $jud['valid'] ) {
+				$runtime = printtimediff($start, NULL);
+			} else {
+				$runtime = '[aborted]';
+			}
+		} else {
+			$runtime = printtimediff($start, strtotime($jud['endtime']));
+		}
+		$link = ' href="submission.php?id=' . (int)$jud['submitid'] .
+			'&amp;jid=' . (int)$jud['judgingid'] . '"';
 		echo '<tr' . ( $jud['valid'] ? '' : ' class="disabled"' ) . '>';
-		echo '<td><a href="' . $link . '">j' . (int)$jud['judgingid'] .
-			'</a></td>';
-		echo '<td>' . printtime($jud['starttime']) . '</td>';
-		echo '<td>' . printtime(@$jud['endtime'])  . '</td>';
-		echo '<td><a href="' . $link . '">' .
-			printresult(@$jud['result'], $jud['valid']) . '</a></td>';
-		echo '<td align="center">' . printyn($jud['valid']) . '</td>';
-		echo '<td align="center">' . printyn($jud['verified']) . '</td>';
+		echo "<td><a$link>j" . (int)$jud['judgingid'] . '</a></td>';
+		echo "<td><a$link>" . printtime($jud['starttime']) . '</a></td>';
+		echo "<td><a$link>" . $runtime . '</a></td>';
+		echo "<td><a$link>" . printresult(@$jud['result'], $jud['valid']) . '</a></td>';
+		echo "<td align=\"center\"><a$link>" . printyn($jud['valid']) . '</a></td>';
+		echo "<td align=\"center\"><a$link>" . printyn($jud['verified']) . '</a></td>';
 		echo "</tr>\n";
 	}
 	echo "</tbody>\n</table>\n\n";
