@@ -3,7 +3,7 @@
 /**
  * Scoreboard
  *
- * $Id: scoreboard.php 3118 2010-02-22 20:23:55Z kink $
+ * $Id: scoreboard.php 3576 2011-07-30 19:48:17Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -14,10 +14,19 @@ $refresh = '30;url=scoreboard.php';
 $title = 'Scoreboard';
 $printercss = TRUE;
 
+// parse filter options
+$filter = array();
+if ( !isset($_GET['clear']) ) {
+	foreach( array('affilid', 'country', 'categoryid') as $type ) {
+		if ( !empty($_GET[$type]) ) $filter[$type] = $_GET[$type];
+	}
+	if ( count($filter) ) $refresh .= '?' . http_build_query($filter);
+}
+
 require(LIBWWWDIR . '/header.php');
 require(LIBWWWDIR . '/scoreboard.php');
 
 // call the general putScoreBoard function from scoreboard.php
-putScoreBoard($cdata);
+putScoreBoard($cdata, NULL, FALSE, $filter);
 
 require(LIBWWWDIR . '/footer.php');
