@@ -2,7 +2,7 @@
 /**
  * View the details of a specific submission
  *
- * $Id: submission.php 3236 2010-07-08 19:17:38Z eldering $
+ * $Id: submission.php 3632 2011-08-27 19:13:39Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -12,18 +12,19 @@ function parseDiff($difftext){
 	$line = strtok($difftext,"\n"); //first line
 	if(sscanf($line, "### DIFFERENCES FROM LINE %d ###\n", $firstdiff) != 1)
 		return htmlspecialchars($difftext);
-	$return = sprintf("### DIFFERENCES FROM <a href='#firstdiff'>LINE %d</a> ###\n", $firstdiff);
+	$return = $line . "\n";
+
+	// Add second line 'team ? reference'
 	$line = strtok("\n");
+	$return .= $line . "\n";
 
-	// We use a heuristic search to find the starting location of the
-	// middle separator (subtract 4 lineno chars, add 1 initial matched char)
-	$midloc = strlen(preg_replace('/[\'_ ] [!=<>\$] \'.*$/', '', $line)) - 4 + 1;
+	// We determine the separator position from the character '?' on
+	// the second line, correct for offset of line numbers
+	$midloc = strpos($line, '?') - 5;
 
+	$line = strtok("\n");
 	while(strlen($line) != 0){
-		$linenostr = substr($line,0,4);
-		if($firstdiff == (int)$linenostr) {
-			$linenostr = "<a id='firstdiff'></a>".$linenostr;
-		}
+		$linenostr = substr($line,0,3);
 		$diffline = substr($line,4);
 		$mid = substr($diffline, $midloc, 3);
 		switch($mid){
@@ -59,11 +60,11 @@ if ( !empty($_GET['jid']) ) $jid = (int)$_GET['jid'];
 if ( is_array(@$_POST['claim']) ) {
 	foreach( $_POST['claim'] as $key => $val ) $id = (int)$key;
 }
-
-$lastverifier = @$_COOKIE['domjudge_lastverifier'];
+if ( is_array(@$_POST['unclaim']) ) {
+	foreach( $_POST['unclaim'] as $key => $val ) $id = (int)$key;
+}
 
 require('init.php');
-require_once(LIBWWWDIR . '/forms.php');
 
 $title = 'Submission s'.@$id;
 
@@ -83,7 +84,7 @@ $submdata = $DB->q('MAYBETUPLE SELECT s.teamid, s.probid, s.langid,
 if ( ! $submdata ) error ("Missing submission data");
 
 $jdata = $DB->q('KEYTABLE SELECT judgingid AS ARRAYKEY, result, valid, starttime,
-                 judgehost, verified, verifier
+                 judgehost, verified, jury_member
                  FROM judging
                  WHERE cid = %i AND submitid = %i
                  ORDER BY starttime ASC, judgingid ASC',
@@ -98,32 +99,29 @@ if ( !isset($jid) ) {
 	}
 }
 
-if ( isset($_POST['claim']) || isset($_POST['unclaim']) ) {
+$jury_member = getJuryMember();
 
-	// Set $lastverifier for default in select-box.
-	$lastverifier = $verifier = getVerifier();
+if ( isset($_REQUEST['claim']) || isset($_REQUEST['unclaim']) ) {
 
-	if ( isset($_POST['unclaim']) ) $verifier = FALSE;
-
-	// Set verifier cookie
-	setVerifier($verifier);
-
-	// Send headers now: after cookies, before possible warning messages.
-	require_once(LIBWWWDIR . '/header.php');
+	// Send headers before possible warning messages.
+	if ( !isset($_REQUEST['unclaim']) ) require_once(LIBWWWDIR . '/header.php');
 
 	if ( !isset($jid) ) {
 		warning("Cannot claim this submission: no valid judging found.");
 	} else if ( $jdata[$jid]['verified'] ) {
 		warning("Cannot claim this submission: judging already verified.");
-	} else if ( empty($verifier) && $verifier!==FALSE ) {
-		warning("Cannot claim this submission: no verifier specified.");
+	} else if ( empty($jury_member) && isset($_REQUEST['claim']) ) {
+		warning("Cannot claim this submission: no jury member specified.");
 	} else {
-		if ( !empty($jdata[$jid]['verifier']) && $verifier!==FALSE ) {
+		if ( !empty($jdata[$jid]['jury_member']) && isset($_REQUEST['claim']) ) {
 			warning("Submission claimed and previous owner " .
-			        @$jdata[$jid]['verifier'] . " replaced.");
+			        @$jdata[$jid]['jury_member'] . " replaced.");
 		}
-		$DB->q('UPDATE judging SET verifier = ' . ($verifier===FALSE ? 'NULL %_ ' : '%s ') .
-		       'WHERE judgingid = %i', $verifier, $jid);
+		$DB->q('UPDATE judging SET jury_member = ' .
+		       (isset($_REQUEST['unclaim']) ? 'NULL %_ ' : '%s ') .
+		       'WHERE judgingid = %i', $jury_member, $jid);
+
+		if ( isset($_REQUEST['unclaim']) ) header('Location: submissions.php');
 	}
 }
 
@@ -141,7 +139,7 @@ if ( $submdata['valid'] ) {
 
 ?>
 <table width="100%">
-<tr><td valign="top">
+<tr><td>
 <table>
 <caption>Submission</caption>
 <tr><td scope="row">Contest:</td><td>
@@ -166,7 +164,7 @@ if ( $submdata['valid'] ) {
 </table>
 
 
-</td><td valign="top">
+</td><td>
 
 <?php
 
@@ -236,14 +234,14 @@ if ( isset($jid) )  {
 		echo addForm($pagename . '?id=' . urlencode($id) . '&jid=' . urlencode($jid));
 
 		echo "<p>Claimed: " .
-		    "<strong>" . printyn(!empty($jud['verifier'])) . "</strong>";
-		if ( empty($jud['verifier']) ) {
+		    "<strong>" . printyn(!empty($jud['jury_member'])) . "</strong>";
+		if ( empty($jud['jury_member']) ) {
 			echo '; ';
 		} else {
-			echo ', by ' . htmlspecialchars($jud['verifier']) . '; ' .
+			echo ', by ' . htmlspecialchars($jud['jury_member']) . '; ' .
 			    addSubmit('unclaim', 'unclaim') . ' or ';
 		}
-		echo addSubmit('claim', 'claim') . ' as ' . addVerifierSelect($lastverifier) .
+		echo addSubmit('claim', 'claim') . ' as ' . addJuryMemberSelect($jury_member) .
 		    addEndForm();
 	}
 
@@ -266,13 +264,13 @@ if ( isset($jid) )  {
 
 			echo "<p>Verified: " .
 			    "<strong>" . printyn($jud['verified']) . "</strong>";
-			if ( $jud['verified'] && ! empty($jud['verifier']) ) {
-				echo ", by " . htmlspecialchars($jud['verifier']);
+			if ( $jud['verified'] && ! empty($jud['jury_member']) ) {
+				echo ", by " . htmlspecialchars($jud['jury_member']);
 			}
 
 			if ( ! (VERIFICATION_REQUIRED && $jud['verified']) ) {
 				echo '; ' . addSubmit(($val ? '' : 'un') . 'mark verified', 'verify');
-				if ( $val ) echo ' by ' . addVerifierSelect($lastverifier);
+				if ( $val ) echo ' by ' . addJuryMemberSelect($jury_member);
 				echo "</p>" . addEndForm();
 			} else {
 				echo "</p>\n";
@@ -299,7 +297,7 @@ if ( isset($jid) )  {
 
 	echo "<h3 id=\"compile\">Compilation output</h3>\n\n";
 
-	if ( @$jud['output_compile'] ) {
+	if ( strlen(@$jud['output_compile']) > 0 ) {
 		echo "<pre class=\"output_text\">".
 			htmlspecialchars($jud['output_compile'])."</pre>\n\n";
 	} elseif ( $jud['output_compile']===NULL ) {
@@ -361,22 +359,22 @@ if ( isset($jid) )  {
 		echo "<table>\n" .
 		    "<tr><td>Description:</td><td>" .
 		    htmlspecialchars($run['description']) . "</td></tr>" .
+		    "<tr><td>Download: </td><td>" .
+		    "<a href=\"testcase.php?probid=" . htmlspecialchars($submdata['probid']) .
+		    "&amp;rank=" . $run['rank'] . "&amp;fetch=input\">Input</a> / " .
+		    "<a href=\"testcase.php?probid=" . htmlspecialchars($submdata['probid']) .
+		    "&amp;rank=" . $run['rank'] . "&amp;fetch=output\">Reference Output</a> / " .
+		    "<a href=\"team_output.php?probid=" . htmlspecialchars($submdata['probid']) .
+		    "&amp;runid=" . $run['runid'] . "\">Team Output</a>" .
+		    "</td></tr>" .
 		    "<tr><td>Runtime:</td><td>$run[runtime] sec</td></tr>" .
 		    "<tr><td>Result: </td><td><span class=\"sol sol_" .
 		    ( $run['runresult']=='correct' ? '' : 'in' ) .
 		    "correct\">$run[runresult]</span></td></tr>" .
 		    "</table>\n\n";
 
-		echo "<h5>Program output</h5>\n";
-		if ( @$run['output_run'] ) {
-			echo "<pre class=\"output_text\">".
-			    htmlspecialchars($run['output_run'])."</pre>\n\n";
-		} else {
-			echo "<p class=\"nodata\">There was no program output.</p>\n";
-		}
-
 		echo "<h5>Diff output</h5>\n";
-		if ( @$run['output_diff'] ) {
+		if ( strlen(@$run['output_diff']) > 0 ) {
 			echo "<pre class=\"output_text\">";
 			echo parseDiff($run['output_diff']);
 			echo "</pre>\n\n";
@@ -384,8 +382,16 @@ if ( isset($jid) )  {
 			echo "<p class=\"nodata\">There was no diff output.</p>\n";
 		}
 
+		echo "<h5>Program output</h5>\n";
+		if ( strlen(@$run['output_run']) > 0 ) {
+			echo "<pre class=\"output_text\">".
+			    htmlspecialchars($run['output_run'])."</pre>\n\n";
+		} else {
+			echo "<p class=\"nodata\">There was no program output.</p>\n";
+		}
+
 		echo "<h5>Error output (info/debug/errors)</h5>\n";
-		if ( @$run['output_error'] ) {
+		if ( strlen(@$run['output_error']) > 0 ) {
 			echo "<pre class=\"output_text\">".
 			    htmlspecialchars($run['output_error'])."</pre>\n\n";
 		} else {
