@@ -2,7 +2,7 @@
 /**
  * View the submissionqueue
  *
- * $Id: submissions.php 3209 2010-06-12 00:13:43Z eldering $
+ * $Id: submissions.php 3508 2010-12-16 20:06:19Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -38,16 +38,22 @@ if ( version_compare(PHP_VERSION, '5.2') >= 0 ) {
 	setcookie('domjudge_submissionview', $view);
 }
 
+$jury_member = getJuryMember();
+
 require(LIBWWWDIR . '/header.php');
 
 echo "<h1>$title</h1>\n\n";
 
+echo addForm('submissions.php') .
+	'<p>Claim submissions/clarifications as ' .
+	addJuryMemberSelect($jury_member) .
+	addSubmit('change') . "</p>" .
+	addEndForm() . "\n";
+
 $restrictions = array();
 if ( $viewtypes[$view] == 'unverified' ) $restrictions['verified'] = 0;
 
-require_once(LIBWWWDIR . '/forms.php');
-
-echo addForm('submissions.php', 'get') . "<p>\n";
+echo addForm('submissions.php', 'get') . "<p>Show submissions:\n";
 for($i=0; $i<count($viewtypes); ++$i) {
 	echo addSubmit($viewtypes[$i], 'view['.$i.']', null, ($view != $i));
 }
