@@ -2,7 +2,7 @@
 /**
  * View a row in team_affiliation: an institution, company etc
  *
- * $Id: team_affiliation.php 3595 2011-08-14 10:06:53Z eldering $
+ * $Id: team_affiliation.php 3588 2011-08-04 07:39:02Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -11,18 +11,17 @@
 $pagename = basename($_SERVER['PHP_SELF']);
 
 require('init.php');
+require(LIBWWWDIR . '/scoreboard.php');
 
 $id = @$_GET['id'];
 $title = "Affiliation: " .htmlspecialchars(@$id);
 
-if ( ! preg_match('/^\w*$/', $id) ) error("Invalid affiliation id");
+if ( ! preg_match('/^' . IDENTIFIER_CHARS . '*$/', $id) ) error("Invalid affiliation id");
 
 $cmd = @$_GET['cmd'];
 
 if ( IS_ADMIN && ($cmd == 'add' || $cmd == 'edit') ) {
 
-	require(LIBWWWDIR . '/forms.php');
-
 	$title = "Affiliation: " . htmlspecialchars($cmd);
 
 	require(LIBWWWDIR . '/header.php');
@@ -55,7 +54,7 @@ if ( IS_ADMIN && ($cmd == 'add' || $cmd == 'edit') ) {
 href="http://www.iso.org/iso/country_codes/iso_3166_code_lists/country_names_and_code_elements.htm"><img
 src="../images/b_help.png" class="smallpicto" alt="?" /></a></td></tr>
 
-<tr><td valign="top"><label for="data_0__comments_">Comments:</label></td>
+<tr><td><label for="data_0__comments_">Comments:</label></td>
 <td><?php echo addTextArea('data[0][comments]', @$row['comments'])?></td></tr>
 
 </table>
@@ -106,7 +105,7 @@ if ( is_readable($countryflag) ) {
 echo "</td></tr>\n";
 
 if ( !empty($data['comments']) ) {
-	echo '<tr><td valign="top" scope="row">Comments:</td><td>' .
+	echo '<tr><td scope="row">Comments:</td><td>' .
 		nl2br(htmlspecialchars($data['comments'])) . "</td></tr>\n";
 }
 
@@ -120,6 +119,7 @@ if ( IS_ADMIN ) {
 
 echo "<h2>Teams from " . htmlspecialchars($data['name']) . "</h2>\n\n";
 
+$listteams = array();
 $teams = $DB->q('SELECT login,name FROM team WHERE affilid = %s', $id);
 if ( $teams->count() == 0 ) {
 	echo "<p class=\"nodata\">no teams</p>\n\n";
@@ -128,12 +128,17 @@ if ( $teams->count() == 0 ) {
 		"<tr><th scope=\"col\">login</th><th scope=\"col\">teamname</th></tr>\n" .
 		"</thead>\n<tbody>\n";
 	while ($team = $teams->next()) {
+		$listteams[] = $team['login'];
 		$link = '<a href="team.php?id=' . urlencode($team['login']) . '">';
 		echo "<tr><td class=\"teamid\">" .
 		$link . htmlspecialchars($team['login']) . "</a></td><td>" .
 		$link . htmlspecialchars($team['name']) . "</a></td></tr>\n";
 	}
 	echo "</tbody>\n</table>\n\n";
+
+	echo "<p>";
+	putTeamRow($cdata,$listteams);
+	echo "</p>\n\n";
 }
 
 require(LIBWWWDIR . '/footer.php');
