@@ -2,7 +2,7 @@
 /**
  * Change the verification status of a given judging.
  *
- * $Id: verify.php 3209 2010-06-12 00:13:43Z eldering $
+ * $Id: verify.php 3487 2010-12-05 12:17:52Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -13,14 +13,14 @@ $id    = @$_POST['id'];
 $val   = @$_POST['val'];
 if ( empty($id) ) error("No judging ID passed to mark as verified.");
 
-$verifier = getVerifier("");
+$jury_member = getJuryMember();
 
-// Explicitly unset verifier when unmarking verified: otherwise this
-// judging would be marked as "viewing".
+// Explicitly unset jury_member when unmarking verified: otherwise this
+// judging would be marked as "claimed".
 $cnt = $DB->q('RETURNAFFECTED UPDATE judging
-               SET verified = %i, verifier = ' . ($val ? '%s ' : 'NULL %_ ') .
+               SET verified = %i, jury_member = ' . ($val ? '%s ' : 'NULL %_ ') .
               'WHERE judgingid = %i',
-              $val, $verifier, $id);
+              $val, $jury_member, $id);
 
 if ( $cnt == 0 ) {
 	error("Judging '$id' not found or nothing changed.");
@@ -44,8 +44,11 @@ if ( VERIFICATION_REQUIRED ) {
 	       $jdata['probid'], $jdata['submitid']);
 }
 
-setVerifier($verifier);
-
-/* redirect back. */
-header('Location: submission.php?id=' .
-	urlencode($jdata['submitid']) . '&jid=' . urlencode($id));
+/* redirect back to submission page or submissions overview depending
+ * on whether judging was (un)verified. */
+if ( $val ) {
+	header('Location: submissions.php');
+} else {
+	header('Location: submission.php?id=' .
+	       urlencode($jdata['submitid']) . '&jid=' . urlencode($id));
+}
