@@ -3,7 +3,7 @@
  * Show clarification thread and reply box.
  * When no id is given, show clarification request box.
  *
- * $Id: clarification.php 3402 2010-10-27 19:47:17Z kink $
+ * $Id: clarification.php 3470 2010-11-29 21:10:09Z kink $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -40,7 +40,7 @@ if ( isset($_POST['submit']) && !empty($_POST['bodytext']) ) {
 	                $_POST['bodytext']);
 
 	// redirect back to the original location
-	header('Location: clarifications.php');
+	header('Location: ./');
 	exit;
 }
 
