@@ -2,7 +2,7 @@
 /**
  * Scoreboard
  *
- * $Id: scoreboard.php 3118 2010-02-22 20:23:55Z kink $
+ * $Id: scoreboard.php 3583 2011-07-31 09:58:07Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -11,9 +11,19 @@
 require('init.php');
 $refresh = '30;url=scoreboard.php';
 $title = 'Scoreboard';
+
+// parse filter options
+$filter = array();
+if ( !isset($_GET['clear']) ) {
+	foreach( array('affilid', 'country', 'categoryid') as $type ) {
+		if ( !empty($_GET[$type]) ) $filter[$type] = $_GET[$type];
+	}
+	if ( count($filter) ) $refresh .= '?' . http_build_query($filter);
+}
+
 require(LIBWWWDIR . '/header.php');
 
 // call the general putScoreBoard function from scoreboad.php
-putScoreBoard($cdata, $login);
+putScoreBoard($cdata, $login, FALSE, $filter);
 
 require(LIBWWWDIR . '/footer.php');
