@@ -2,7 +2,7 @@
 /**
  * Gives a team the details of a judging of their submission: errors etc.
  *
- * $Id: submission_details.php 3209 2010-06-12 00:13:43Z eldering $
+ * $Id: submission_details.php 3632 2011-08-27 19:13:39Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -56,16 +56,18 @@ if ( (SHOW_COMPILE == 2) ||
 
 	echo "<h2>Compilation output</h2>\n\n";
 
-	if(@$row['output_compile']) {
+	if ( strlen(@$row['output_compile']) > 0 ) {
 		echo "<pre class=\"output_text\">\n".
 			htmlspecialchars(@$row['output_compile'])."\n</pre>\n\n";
-
-		echo "<p><em>Compilation " .
-			( $row['result']=='compiler-error' ? 'failed' : 'successful' ) .
-			"</em></p>\n";
 	} else {
 		echo "<p class=\"nodata\">There were no compiler errors or warnings.</p>\n";
 	}
+
+	if ( $row['result'] == 'compiler-error' ) {
+		echo "<p class=\"compilation-error\">Compilation failed.</p>\n";
+	} else {
+		echo "<p class=\"compilation-success\">Compilation successful.</p>\n";
+	}
 } else {
 	echo "<p class=\"nodata\">Compilation output is disabled.</p>\n";
 }
