@@ -2,7 +2,7 @@
 /**
  * Handle web submissions
  *
- * $Id: upload.php 3209 2010-06-12 00:13:43Z eldering $
+ * $Id: upload.php 3569 2011-07-17 17:35:31Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -20,7 +20,7 @@ if ( ! ENABLE_WEBSUBMIT_SERVER ) {
 
 if ( !isset($_POST['submit']) ) {
 	if (NONINTERACTIVE) error("No 'submit' done.");
-	header('Location: websubmit.php');
+	header('Location: ./');
 	return;
 }
 if ( is_null($cid) ) {
@@ -39,9 +39,17 @@ if ( difftime($cdata['starttime'], $now) > 0 ) {
 
 
 /** helper to output an error message. */
-function err($string) {
+function err($string)
+{
+	// Annoying PHP: we need to import all global variables here...
+	global $nunread_clars, $title, $ajaxtitle, $refresh, $menu;
+
 	if (NONINTERACTIVE) error($string);
 
+	require(LIBWWWDIR . '/header.php');
+
+	echo "<h2>Submit - error</h2>\n\n";
+
 	echo '<div id="uploadstatus">';
 	logmsg(LOG_WARNING, $string);
 	echo '</div>';
@@ -52,24 +60,12 @@ function err($string) {
 
 ini_set("upload_max_filesize", SOURCESIZE * 1024);
 
-require(LIBWWWDIR . '/header.php');
-
-echo "<h2>Submit - upload status</h2>\n\n";
-
 checkFileUpload($_FILES['code']['error']);
 
 $filename = $_FILES['code']['name'];
 
 /* Determine the problem */
 $probid = @$_POST['probid'];
-
-if ( empty($probid) ) {
-	if ( strpos($filename, '.') === false ) {
-		err('Unable to autodetect the problem from the uploaded filename');
-	}
-	$probid = strtolower(substr($filename, 0, strpos($filename, '.')));
-}
-
 $prob = $DB->q('MAYBETUPLE SELECT probid, name FROM problem
                 WHERE allow_submit = 1 AND probid = %s AND cid = %i',
                $probid, $cid);
@@ -78,44 +74,26 @@ if ( ! isset($prob) ) err("Unable to find problem '$probid'");
 $probid = $prob['probid'];
 
 /* Determine the language */
-$langext = @$_POST['langext'];
+$langid = @$_POST['langid'];
+$lang = $DB->q('MAYBETUPLE SELECT langid, name FROM language
+                WHERE langid = %s AND allow_submit = 1', $langid);
 
-if ( empty($langext) ) {
-	if ( strrpos($filename, '.') === false ) {
-		err('Unable to autodetect the language from the uploaded filename');
-	}
-	$fileext = strtolower(substr($filename, strrpos($filename, '.')+1));
+if ( ! isset($lang) ) err("Unable to find language '$langid'");
+$langid = $lang['langid'];
 
-	$all_lang_exts = explode(" ", LANG_EXTS);
+$sid = submit_solution($login, $probid, $langid, $_FILES['code']['tmp_name']);
 
-	foreach ($all_lang_exts as $langextlist) {
-		$langexts = explode(",", $langextlist);
-
-		// Skip first element: that's the language name
-		for ($i = 1; $i < count($langexts); $i++) {
-			if ( $langexts[$i]==$fileext ) $langext = $langexts[1];
-		}
-	}
-
-	if ( empty($langext) ) err("Unable to find language for extension '$fileext'");
+// Redirect back to index page when interactively used.
+if ( !NONINTERACTIVE ) {
+	header('Location: index.php?submitted=' . urlencode($sid) );
 }
 
-$lang = $DB->q('MAYBETUPLE SELECT langid, name, extension FROM language
-                WHERE extension = %s AND allow_submit = 1', $langext);
-
-if ( ! isset($lang) ) err("Unable to find language '$langext'");
-$langext = $lang['extension'];
-
-echo "<table>\n" .
-	"<tr><td>Problem: </td><td><i>".htmlspecialchars($prob['name'])."</i></td></tr>\n" .
-	"<tr><td>Language:</td><td><i>".htmlspecialchars($lang['name'])."</i></td></tr>\n" .
-	"</table>\n";
-
-submit_solution($login, $probid, $langext, $_FILES['code']['tmp_name']);
+require(LIBWWWDIR . '/header.php');
 
 echo '<div id="uploadstatus">';
 if (NONINTERACTIVE) echo '<!-- noninteractive-upload-successful -->';
-echo "<p>Upload successful.</p>";
+echo "<p><a href=\"index.php?submitted=" . urlencode($sid) . "\">Submission successful.</a></p>";
 echo "</div>\n";
 
 require(LIBWWWDIR . '/footer.php');
+
